@@ -175,6 +175,7 @@ bool Audio::setSourceFileName(QString filename)
     if (m_decoder == NULL)
         return false;
 
+    setDuration(m_decoder->totalTime());
     setTotalDuration(m_decoder->totalTime());
 
     emit changed(id());
@@ -404,12 +405,15 @@ void Audio::write(MasterTimer* timer, QList<Universe *> universes)
 
     incrementElapsed();
 
-    uint fadeout = overrideFadeOutSpeed() == defaultSpeed() ? fadeOutSpeed() : overrideFadeOutSpeed();
-
-    if (fadeout)
+    if (m_audio_out && !m_audio_out->isLooped())
     {
-        if (m_audio_out != NULL && totalDuration() - elapsed() <= fadeOutSpeed())
-            m_audio_out->setFadeOut(fadeOutSpeed());
+        uint fadeout = overrideFadeOutSpeed() == defaultSpeed() ? fadeOutSpeed() : overrideFadeOutSpeed();
+
+        if (fadeout)
+        {
+            if (m_audio_out != NULL && totalDuration() - elapsed() <= fadeOutSpeed())
+                m_audio_out->setFadeOut(fadeOutSpeed());
+        }
     }
 }
 
