@@ -520,6 +520,7 @@ void Function::setTempoType(const Function::TempoType &type)
     }
 
     emit changed(m_id);
+    emit tempoTypeChanged();
 }
 
 Function::TempoType Function::tempoType() const
@@ -958,12 +959,16 @@ QList<quint32> Function::components()
  * Flash
  *****************************************************************************/
 
-void Function::flash(MasterTimer *timer)
+void Function::flash(MasterTimer *timer, bool shouldOverride, bool forceLTP)
 {
     Q_UNUSED(timer);
+    Q_UNUSED(shouldOverride);
+    Q_UNUSED(forceLTP);
 
     if (m_flashing == false)
+    {
         emit flashing(m_id, true);
+    }
 
     m_flashing = true;
 }
@@ -1266,7 +1271,7 @@ int Function::requestAttributeOverride(int attributeIndex, qreal value)
         attributeID = m_lastOverrideAttributeId;
         m_overrideMap[attributeID] = override;
 
-        qDebug() << name() << "Override requested for attribute" << attributeIndex << "value" << value << "new ID" << attributeID;
+        qDebug() << name() << "Override requested for new attribute" << attributeIndex << "value" << value << "new ID" << attributeID;
 
         calculateOverrideValue(attributeIndex);
 
@@ -1274,7 +1279,7 @@ int Function::requestAttributeOverride(int attributeIndex, qreal value)
     }
     else
     {
-        qDebug() << name() << "Override requested for attribute" << attributeIndex << "value" << value << "single ID" << attributeID;
+        qDebug() << name() << "Override requested for existing attribute" << attributeIndex << "value" << value << "single ID" << attributeID;
     }
 
     // actually apply the new override value
@@ -1333,13 +1338,13 @@ int Function::adjustAttribute(qreal value, int attributeId)
         if (attributeId >= m_attributes.count() || m_attributes[attributeId].m_value == value)
             return -1;
 
-        // Adjust the original value of an attribute. Only Function editors should do this !
+        // Adjust the original value of an attribute. Only Function editors should do this!
         m_attributes[attributeId].m_value = CLAMP(value, m_attributes[attributeId].m_min, m_attributes[attributeId].m_max);
         attrIndex = attributeId;
     }
     else
     {
-        if (m_overrideMap.contains(attributeId) == false || m_overrideMap[attributeId].m_value == value)
+        if (m_overrideMap.contains(attributeId) == false)
             return -1;
 
         // Adjust an attribute override value and recalculate the final overridden value
@@ -1381,7 +1386,7 @@ int Function::getAttributeIndex(QString name) const
     for (int i = 0; i < m_attributes.count(); i++)
     {
         Attribute attr = m_attributes.at(i);
-        if(attr.m_name == name)
+        if (attr.m_name == name)
             return i;
     }
     return -1;
