@@ -32,10 +32,8 @@
 
 #include "inputoutputmap.h"
 #include "genericfader.h"
-#include "fadechannel.h"
 #include "mastertimer.h"
 #include "dmxsource.h"
-#include "qlcmacros.h"
 #include "function.h"
 #include "universe.h"
 #include "doc.h"
@@ -266,6 +264,8 @@ void MasterTimer::timerTickFunctions(QList<Universe *> universes)
                     removeList << i; // Don't remove the item from the list just yet.
                     functionListHasChanged = true;
                     stoppedAFunction = true;
+
+                    emit functionStopped(function->id());
                 }
             }
         }
