@@ -48,43 +48,48 @@
         <source>Priority</source>
         <translation>Priorita</translation>
     </message>
+    <message>
+        <location filename="configuree131.ui" line="101"/>
+        <source>Seconds to wait for an interface to be ready</source>
+        <translation type="unfinished"></translation>
+    </message>
     <message>
         <location filename="configuree131.ui" line="61"/>
         <source>Universe</source>
         <translation>Větev</translation>
     </message>
     <message>
-        <location filename="configuree131.cpp" line="86"/>
+        <location filename="configuree131.cpp" line="92"/>
         <source>Inputs</source>
         <translation>Vstupy</translation>
     </message>
     <message>
-        <location filename="configuree131.cpp" line="92"/>
+        <location filename="configuree131.cpp" line="98"/>
         <source>Outputs</source>
         <translation>Výstupy</translation>
     </message>
     <message>
-        <location filename="configuree131.cpp" line="176"/>
+        <location filename="configuree131.cpp" line="182"/>
         <source>Full</source>
         <translation>Plný</translation>
     </message>
     <message>
-        <location filename="configuree131.cpp" line="177"/>
+        <location filename="configuree131.cpp" line="183"/>
         <source>Partial</source>
         <translation>Částečný</translation>
     </message>
     <message>
-        <location filename="configuree131.cpp" line="185"/>
+        <location filename="configuree131.cpp" line="191"/>
         <source>%1 - min, %2 - default, %3 - max</source>
         <translation>%1 - nejnižší, %2 - základní, %3 - nejvyšší</translation>
     </message>
     <message>
-        <location filename="configuree131.cpp" line="216"/>
+        <location filename="configuree131.cpp" line="238"/>
         <source>Invalid IP</source>
         <translation>Neplatná IP adresa</translation>
     </message>
     <message>
-        <location filename="configuree131.cpp" line="216"/>
+        <location filename="configuree131.cpp" line="238"/>
         <source>%1 is not a valid IP.
 Please fix it before confirming.</source>
         <translation>%1 není platná IP adresa.
@@ -94,39 +99,39 @@ Prosím opravte zadání před potvrzením.</translation>
 <context>
     <name>E131Plugin</name>
     <message>
-        <location filename="e131plugin.cpp" line="93"/>
+        <location filename="e131plugin.cpp" line="97"/>
         <source>This plugin provides DMX output for devices supporting the E1.31 communication protocol.</source>
         <translation>Tento plugin umožňuje podporu DMX výstupu pro zařízení podporující komunikační protokol E1.31.</translation>
     </message>
     <message>
-        <location filename="e131plugin.cpp" line="140"/>
+        <location filename="e131plugin.cpp" line="144"/>
         <source>Output</source>
         <translation>Výstup</translation>
     </message>
     <message>
-        <location filename="e131plugin.cpp" line="144"/>
-        <location filename="e131plugin.cpp" line="284"/>
+        <location filename="e131plugin.cpp" line="148"/>
+        <location filename="e131plugin.cpp" line="287"/>
         <source>Status: Not open</source>
         <translation>Stav: Není otevřen</translation>
     </message>
     <message>
-        <location filename="e131plugin.cpp" line="147"/>
-        <location filename="e131plugin.cpp" line="287"/>
+        <location filename="e131plugin.cpp" line="151"/>
+        <location filename="e131plugin.cpp" line="290"/>
         <source>Status: Open</source>
         <translation>Stav: Otevřen</translation>
     </message>
     <message>
-        <location filename="e131plugin.cpp" line="149"/>
+        <location filename="e131plugin.cpp" line="153"/>
         <source>Packets sent: </source>
         <translation>Odeslané pakety:</translation>
     </message>
     <message>
-        <location filename="e131plugin.cpp" line="280"/>
+        <location filename="e131plugin.cpp" line="283"/>
         <source>Input</source>
         <translation>Vstup</translation>
     </message>
     <message>
-        <location filename="e131plugin.cpp" line="289"/>
+        <location filename="e131plugin.cpp" line="292"/>
         <source>Packets received: </source>
         <translation>Přijaté pakety:</translation>
     </message>
