@@ -48,43 +48,48 @@
         <source>Priority</source>
         <translation>Priorité</translation>
     </message>
+    <message>
+        <location filename="configuree131.ui" line="101"/>
+        <source>Seconds to wait for an interface to be ready</source>
+        <translation type="unfinished"></translation>
+    </message>
     <message>
         <location filename="configuree131.ui" line="61"/>
         <source>Universe</source>
         <translation>Univers</translation>
     </message>
     <message>
-        <location filename="configuree131.cpp" line="86"/>
+        <location filename="configuree131.cpp" line="92"/>
         <source>Inputs</source>
         <translation>Entrées</translation>
     </message>
     <message>
-        <location filename="configuree131.cpp" line="92"/>
+        <location filename="configuree131.cpp" line="98"/>
         <source>Outputs</source>
         <translation>Sorties</translation>
     </message>
     <message>
-        <location filename="configuree131.cpp" line="176"/>
+        <location filename="configuree131.cpp" line="182"/>
         <source>Full</source>
         <translation>Complète</translation>
     </message>
     <message>
-        <location filename="configuree131.cpp" line="177"/>
+        <location filename="configuree131.cpp" line="183"/>
         <source>Partial</source>
         <translation>Partielle</translation>
     </message>
     <message>
-        <location filename="configuree131.cpp" line="185"/>
+        <location filename="configuree131.cpp" line="191"/>
         <source>%1 - min, %2 - default, %3 - max</source>
         <translation>%1 - min, %2 - défaut, %3 - max</translation>
     </message>
     <message>
-        <location filename="configuree131.cpp" line="216"/>
+        <location filename="configuree131.cpp" line="238"/>
         <source>Invalid IP</source>
         <translation>IP invalide</translation>
     </message>
     <message>
-        <location filename="configuree131.cpp" line="216"/>
+        <location filename="configuree131.cpp" line="238"/>
         <source>%1 is not a valid IP.
 Please fix it before confirming.</source>
         <translation>%1 n&apos;est pas une IP valide.
@@ -94,39 +99,39 @@ Veuillez la corriger avant de valider.</translation>
 <context>
     <name>E131Plugin</name>
     <message>
-        <location filename="e131plugin.cpp" line="93"/>
+        <location filename="e131plugin.cpp" line="97"/>
         <source>This plugin provides DMX output for devices supporting the E1.31 communication protocol.</source>
         <translation>Ce plugin offre le support des périphériques supportant le protocole E1.31.</translation>
     </message>
     <message>
-        <location filename="e131plugin.cpp" line="140"/>
+        <location filename="e131plugin.cpp" line="144"/>
         <source>Output</source>
         <translation>Sortie</translation>
     </message>
     <message>
-        <location filename="e131plugin.cpp" line="144"/>
-        <location filename="e131plugin.cpp" line="284"/>
+        <location filename="e131plugin.cpp" line="148"/>
+        <location filename="e131plugin.cpp" line="287"/>
         <source>Status: Not open</source>
         <translation>Status : fermé</translation>
     </message>
     <message>
-        <location filename="e131plugin.cpp" line="147"/>
-        <location filename="e131plugin.cpp" line="287"/>
+        <location filename="e131plugin.cpp" line="151"/>
+        <location filename="e131plugin.cpp" line="290"/>
         <source>Status: Open</source>
         <translation>Status : ouvert</translation>
     </message>
     <message>
-        <location filename="e131plugin.cpp" line="149"/>
+        <location filename="e131plugin.cpp" line="153"/>
         <source>Packets sent: </source>
         <translation>Paquets envoyés : </translation>
     </message>
     <message>
-        <location filename="e131plugin.cpp" line="280"/>
+        <location filename="e131plugin.cpp" line="283"/>
         <source>Input</source>
         <translation>Entrée</translation>
     </message>
     <message>
-        <location filename="e131plugin.cpp" line="289"/>
+        <location filename="e131plugin.cpp" line="292"/>
         <source>Packets received: </source>
         <translation>Paquets reçus : </translation>
     </message>
