@@ -18,10 +18,11 @@
 */
 
 #include <QTreeWidgetItem>
+#include <QMessageBox>
+#include <QSettings>
 #include <QCheckBox>
 #include <QComboBox>
 #include <QLineEdit>
-#include <QMessageBox>
 #include <QSpinBox>
 #include <QLabel>
 #include <QString>
@@ -47,6 +48,8 @@
 #define E131_PRIORITY_MIN 0
 #define E131_PRIORITY_MAX 200
 
+#define SETTINGS_GEOMETRY "conifguree131/geometry"
+
 /*****************************************************************************
  * Initialization
  *****************************************************************************/
@@ -61,10 +64,20 @@ ConfigureE131::ConfigureE131(E131Plugin* plugin, QWidget* parent)
     setupUi(this);
 
     fillMappingTree();
+
+    QSettings settings;
+    QVariant value = settings.value(SETTINGS_IFACE_WAIT_TIME);
+    if (value.isValid() == true)
+        m_waitReadySpin->setValue(value.toInt());
+    QVariant geometrySettings = settings.value(SETTINGS_GEOMETRY);
+    if (geometrySettings.isValid() == true)
+        restoreGeometry(geometrySettings.toByteArray());
 }
 
 ConfigureE131::~ConfigureE131()
 {
+    QSettings settings;
+    settings.setValue(SETTINGS_GEOMETRY, saveGeometry());
 }
 
 void ConfigureE131::fillMappingTree()
@@ -73,7 +86,7 @@ void ConfigureE131::fillMappingTree()
     QTreeWidgetItem* outputItem = NULL;
 
     QList<E131IO> IOmap = m_plugin->getIOMapping();
-    foreach(E131IO io, IOmap)
+    foreach (E131IO io, IOmap)
     {
         E131Controller *controller = io.controller;
         if (controller == NULL)
@@ -92,7 +105,7 @@ void ConfigureE131::fillMappingTree()
             outputItem->setText(KMapColumnInterface, tr("Outputs"));
             outputItem->setExpanded(true);
         }
-        foreach(quint32 universe, controller->universesList())
+        foreach (quint32 universe, controller->universesList())
         {
             UniverseInfo *info = controller->getUniverseInfo(universe);
             qDebug() << Q_FUNC_INFO << "uni" << universe << "type" << info->type;
@@ -396,7 +409,7 @@ void ConfigureE131::accept()
                         E131_UNIVERSE, universeSpin->value());
 
                 QComboBox* transCombo = qobject_cast<QComboBox*>(m_uniMapTree->itemWidget(item, KMapColumnTransmitMode));
-                if(transCombo->currentIndex() == 1)
+                if (transCombo->currentIndex() == 1)
                     m_plugin->setParameter(universe, line, QLCIOPlugin::Output,
                             E131_TRANSMITMODE, E131Controller::transmissionModeToString(E131Controller::Partial));
                 else
@@ -410,6 +423,13 @@ void ConfigureE131::accept()
         }
     }
 
+    QSettings settings;
+    int waitTime = m_waitReadySpin->value();
+    if (waitTime == 0)
+        settings.remove(SETTINGS_IFACE_WAIT_TIME);
+    else
+        settings.setValue(SETTINGS_IFACE_WAIT_TIME, waitTime);
+
     QDialog::accept();
 }
 
