@@ -4,75 +4,75 @@
 <context>
     <name>ArtNetPlugin</name>
     <message>
-        <location filename="artnetplugin.cpp" line="93"/>
+        <location filename="artnetplugin.cpp" line="97"/>
         <source>This plugin provides DMX output for devices supporting the ArtNet communication protocol.</source>
         <oldsource>This plugin provides output for devices supporting the ArtNet communication protocol.</oldsource>
         <translation>Este plugin provee Salida DMX para dispositivos que soportan el protocolo de comunicación ArtNet.</translation>
     </message>
     <message>
-        <location filename="artnetplugin.cpp" line="140"/>
+        <location filename="artnetplugin.cpp" line="144"/>
         <source>Output</source>
         <translation>Salida</translation>
     </message>
     <message>
-        <location filename="artnetplugin.cpp" line="144"/>
-        <location filename="artnetplugin.cpp" line="295"/>
+        <location filename="artnetplugin.cpp" line="148"/>
+        <location filename="artnetplugin.cpp" line="298"/>
         <source>Status: Not open</source>
         <translation>Estado: No abierto</translation>
     </message>
     <message>
-        <location filename="artnetplugin.cpp" line="147"/>
+        <location filename="artnetplugin.cpp" line="151"/>
         <source>Status: Open</source>
         <translation>Estado: Abierto</translation>
     </message>
     <message>
-        <location filename="artnetplugin.cpp" line="152"/>
+        <location filename="artnetplugin.cpp" line="156"/>
         <source>No</source>
         <translation>No</translation>
     </message>
     <message>
-        <location filename="artnetplugin.cpp" line="154"/>
+        <location filename="artnetplugin.cpp" line="158"/>
         <source>Yes</source>
         <translation>Sí</translation>
     </message>
     <message>
-        <location filename="artnetplugin.cpp" line="155"/>
+        <location filename="artnetplugin.cpp" line="159"/>
         <source>Can receive nodes information</source>
         <oldsource>Can receive node information</oldsource>
         <translation>Puede recibir información de nodos</translation>
     </message>
     <message>
-        <location filename="artnetplugin.cpp" line="158"/>
+        <location filename="artnetplugin.cpp" line="162"/>
         <source>Nodes discovered: </source>
         <translation>Nodos descubiertos: </translation>
     </message>
     <message>
-        <location filename="artnetplugin.cpp" line="161"/>
+        <location filename="artnetplugin.cpp" line="165"/>
         <source>Packets sent: </source>
         <translation>Paquetes enviados: </translation>
     </message>
     <message>
-        <location filename="artnetplugin.cpp" line="291"/>
+        <location filename="artnetplugin.cpp" line="294"/>
         <source>Input</source>
         <translation>Entrada</translation>
     </message>
     <message>
-        <location filename="artnetplugin.cpp" line="300"/>
+        <location filename="artnetplugin.cpp" line="303"/>
         <source>Bind failed</source>
         <translation>Falló el enlace</translation>
     </message>
     <message>
-        <location filename="artnetplugin.cpp" line="302"/>
+        <location filename="artnetplugin.cpp" line="305"/>
         <source>Open</source>
         <translation>Abierto</translation>
     </message>
     <message>
-        <location filename="artnetplugin.cpp" line="303"/>
+        <location filename="artnetplugin.cpp" line="306"/>
         <source>Status</source>
         <translation>Estado</translation>
     </message>
     <message>
-        <location filename="artnetplugin.cpp" line="306"/>
+        <location filename="artnetplugin.cpp" line="309"/>
         <source>Packets received: </source>
         <translation>Paquetes recibidos: </translation>
     </message>
@@ -120,57 +120,67 @@
         <translation>Modo de Transmisión</translation>
     </message>
     <message>
-        <location filename="configureartnet.ui" line="86"/>
+        <location filename="configureartnet.ui" line="87"/>
+        <source>Seconds to wait for an interface to be ready</source>
+        <translation>Segundos a esperar que esté preparada una interfaz</translation>
+    </message>
+    <message>
+        <location filename="configureartnet.ui" line="120"/>
         <source>Nodes Tree</source>
         <translation>Árbol de Nodos</translation>
     </message>
     <message>
-        <location filename="configureartnet.ui" line="96"/>
+        <location filename="configureartnet.ui" line="130"/>
         <source>IP</source>
         <translation>IP</translation>
     </message>
     <message>
-        <location filename="configureartnet.ui" line="101"/>
+        <location filename="configureartnet.ui" line="135"/>
         <source>Short Name</source>
         <translation>Nombre Corto</translation>
     </message>
     <message>
-        <location filename="configureartnet.ui" line="106"/>
+        <location filename="configureartnet.ui" line="140"/>
         <source>Long Name</source>
         <translation>Nombre Largo</translation>
     </message>
     <message>
-        <location filename="configureartnet.cpp" line="80"/>
+        <location filename="configureartnet.cpp" line="86"/>
         <source>%1 nodes</source>
         <translation>%1 nodos</translation>
     </message>
     <message>
-        <location filename="configureartnet.cpp" line="118"/>
+        <location filename="configureartnet.cpp" line="124"/>
         <source>Inputs</source>
         <translation>Entradas</translation>
     </message>
     <message>
-        <location filename="configureartnet.cpp" line="124"/>
+        <location filename="configureartnet.cpp" line="130"/>
         <source>Outputs</source>
         <translation>Salidas</translation>
     </message>
     <message>
-        <location filename="configureartnet.cpp" line="175"/>
+        <location filename="configureartnet.cpp" line="181"/>
+        <source>Standard</source>
+        <translation>Estándar</translation>
+    </message>
+    <message>
+        <location filename="configureartnet.cpp" line="182"/>
         <source>Full</source>
         <translation>Completo</translation>
     </message>
     <message>
-        <location filename="configureartnet.cpp" line="176"/>
+        <location filename="configureartnet.cpp" line="183"/>
         <source>Partial</source>
         <translation>Parcial</translation>
     </message>
     <message>
-        <location filename="configureartnet.cpp" line="189"/>
+        <location filename="configureartnet.cpp" line="198"/>
         <source>Invalid IP</source>
         <translation>IP inválido</translation>
     </message>
     <message>
-        <location filename="configureartnet.cpp" line="189"/>
+        <location filename="configureartnet.cpp" line="198"/>
         <source>%1 is not a valid IP.
 Please fix it before confirming.</source>
         <translation>%1 no es un IP válido.
