@@ -136,9 +136,10 @@ QString GPIOPlugin::outputInfo(quint32 output)
     return str;
 }
 
-void GPIOPlugin::writeUniverse(quint32 universe, quint32 output, const QByteArray &data)
+void GPIOPlugin::writeUniverse(quint32 universe, quint32 output, const QByteArray &data, bool dataChanged)
 {
     Q_UNUSED(universe)
+    Q_UNUSED(dataChanged)
 
     if (output != 0)
         return;
