@@ -40,37 +40,42 @@
         <translation>Ausgangsport</translation>
     </message>
     <message>
-        <location filename="configureosc.ui" line="88"/>
+        <location filename="configureosc.ui" line="90"/>
+        <source>Seconds to wait for an interface to be ready</source>
+        <translation>Sekunden um auf die Bereitschaft eines Interfaces zu warten</translation>
+    </message>
+    <message>
+        <location filename="configureosc.ui" line="122"/>
         <source>Channel number calculator</source>
         <translation>Kanalnummer-Rechner</translation>
     </message>
     <message>
-        <location filename="configureosc.ui" line="96"/>
+        <location filename="configureosc.ui" line="130"/>
         <source>OSC path</source>
         <translation>OSC-Pfad</translation>
     </message>
     <message>
-        <location filename="configureosc.ui" line="106"/>
+        <location filename="configureosc.ui" line="140"/>
         <source>Channel number</source>
         <translation>Kanal-Nummer</translation>
     </message>
     <message>
-        <location filename="configureosc.cpp" line="83"/>
+        <location filename="configureosc.cpp" line="88"/>
         <source>Inputs</source>
         <translation>Eingänge</translation>
     </message>
     <message>
-        <location filename="configureosc.cpp" line="89"/>
+        <location filename="configureosc.cpp" line="94"/>
         <source>Outputs</source>
         <translation>Ausgänge</translation>
     </message>
     <message>
-        <location filename="configureosc.cpp" line="171"/>
+        <location filename="configureosc.cpp" line="176"/>
         <source>Invalid IP</source>
         <translation>Ungültige IP</translation>
     </message>
     <message>
-        <location filename="configureosc.cpp" line="171"/>
+        <location filename="configureosc.cpp" line="176"/>
         <source>%1 is not a valid IP.
 Please fix it before confirming.</source>
         <translation>%1 ist keine gültige IP.
@@ -80,39 +85,39 @@ Bitte vor Bestätigung korrigieren.</translation>
 <context>
     <name>OSCPlugin</name>
     <message>
-        <location filename="oscplugin.cpp" line="91"/>
+        <location filename="oscplugin.cpp" line="96"/>
         <source>This plugin provides input for devices supporting the OSC transmission protocol.</source>
         <translation>Dieses Plugin bietet Eingabunterstützung für Geräte mit dem OSC-Protokoll.</translation>
     </message>
     <message>
-        <location filename="oscplugin.cpp" line="142"/>
-        <location filename="oscplugin.cpp" line="276"/>
+        <location filename="oscplugin.cpp" line="147"/>
+        <location filename="oscplugin.cpp" line="280"/>
         <source>Status: Not open</source>
         <translation>Status: Nicht geöffnet</translation>
     </message>
     <message>
-        <location filename="oscplugin.cpp" line="145"/>
-        <location filename="oscplugin.cpp" line="279"/>
+        <location filename="oscplugin.cpp" line="150"/>
+        <location filename="oscplugin.cpp" line="283"/>
         <source>Status: Open</source>
         <translation>Status: Geöffnet</translation>
     </message>
     <message>
-        <location filename="oscplugin.cpp" line="147"/>
+        <location filename="oscplugin.cpp" line="152"/>
         <source>Packets sent: </source>
         <translation>Pakete gesendet: </translation>
     </message>
     <message>
-        <location filename="oscplugin.cpp" line="281"/>
+        <location filename="oscplugin.cpp" line="285"/>
         <source>Packets received: </source>
         <translation>Pakete empfangen: </translation>
     </message>
     <message>
-        <location filename="oscplugin.cpp" line="138"/>
+        <location filename="oscplugin.cpp" line="143"/>
         <source>Output</source>
         <translation>Ausgang</translation>
     </message>
     <message>
-        <location filename="oscplugin.cpp" line="272"/>
+        <location filename="oscplugin.cpp" line="276"/>
         <source>Input</source>
         <translation>Eingang</translation>
     </message>
