@@ -40,79 +40,84 @@
         <translation>Puerto de Salida</translation>
     </message>
     <message>
-        <location filename="configureosc.ui" line="88"/>
+        <location filename="configureosc.ui" line="90"/>
+        <source>Seconds to wait for an interface to be ready</source>
+        <translation>Segundos a esperar que esté preparada una interfaz</translation>
+    </message>
+    <message>
+        <location filename="configureosc.ui" line="122"/>
         <source>Channel number calculator</source>
-        <translation type="unfinished"></translation>
+        <translation>Calculadora de número de canal</translation>
     </message>
     <message>
-        <location filename="configureosc.ui" line="96"/>
+        <location filename="configureosc.ui" line="130"/>
         <source>OSC path</source>
-        <translation type="unfinished"></translation>
+        <translation>Ruta OSC</translation>
     </message>
     <message>
-        <location filename="configureosc.ui" line="106"/>
+        <location filename="configureosc.ui" line="140"/>
         <source>Channel number</source>
-        <translation type="unfinished"></translation>
+        <translation>Número de canal</translation>
     </message>
     <message>
-        <location filename="configureosc.cpp" line="83"/>
+        <location filename="configureosc.cpp" line="88"/>
         <source>Inputs</source>
         <translation>Entradas</translation>
     </message>
     <message>
-        <location filename="configureosc.cpp" line="89"/>
+        <location filename="configureosc.cpp" line="94"/>
         <source>Outputs</source>
         <translation>Salidas</translation>
     </message>
     <message>
-        <location filename="configureosc.cpp" line="171"/>
+        <location filename="configureosc.cpp" line="176"/>
         <source>Invalid IP</source>
         <translation>IP Inválido</translation>
     </message>
     <message>
-        <location filename="configureosc.cpp" line="171"/>
+        <location filename="configureosc.cpp" line="176"/>
         <source>%1 is not a valid IP.
 Please fix it before confirming.</source>
-        <translation>%1 no es un IP válidoo.
+        <translation>%1 no es un IP válido.
 Por favor arréglelo antes de confirmar.</translation>
     </message>
 </context>
 <context>
     <name>OSCPlugin</name>
     <message>
-        <location filename="oscplugin.cpp" line="91"/>
+        <location filename="oscplugin.cpp" line="96"/>
         <source>This plugin provides input for devices supporting the OSC transmission protocol.</source>
         <translation>Este plugin provee Entrada para dispositivos que soportan el protocolo de transmisión OSC.</translation>
     </message>
     <message>
-        <location filename="oscplugin.cpp" line="142"/>
-        <location filename="oscplugin.cpp" line="276"/>
+        <location filename="oscplugin.cpp" line="147"/>
+        <location filename="oscplugin.cpp" line="280"/>
         <source>Status: Not open</source>
         <translation>Estado: No abierto</translation>
     </message>
     <message>
-        <location filename="oscplugin.cpp" line="145"/>
-        <location filename="oscplugin.cpp" line="279"/>
+        <location filename="oscplugin.cpp" line="150"/>
+        <location filename="oscplugin.cpp" line="283"/>
         <source>Status: Open</source>
         <translation>Estado: Abierto</translation>
     </message>
     <message>
-        <location filename="oscplugin.cpp" line="147"/>
+        <location filename="oscplugin.cpp" line="152"/>
         <source>Packets sent: </source>
         <translation>Paquetes enviados: </translation>
     </message>
     <message>
-        <location filename="oscplugin.cpp" line="281"/>
+        <location filename="oscplugin.cpp" line="285"/>
         <source>Packets received: </source>
         <translation>Paquetes recibidos: </translation>
     </message>
     <message>
-        <location filename="oscplugin.cpp" line="138"/>
+        <location filename="oscplugin.cpp" line="143"/>
         <source>Output</source>
         <translation>Salida</translation>
     </message>
     <message>
-        <location filename="oscplugin.cpp" line="272"/>
+        <location filename="oscplugin.cpp" line="276"/>
         <source>Input</source>
         <translation>Entrada</translation>
     </message>
