@@ -40,37 +40,42 @@
         <translation>Porta di trasmissione</translation>
     </message>
     <message>
-        <location filename="configureosc.ui" line="88"/>
+        <location filename="configureosc.ui" line="90"/>
+        <source>Seconds to wait for an interface to be ready</source>
+        <translation>Secondi di attesa affinchè un&apos;interfaccia sia pronta</translation>
+    </message>
+    <message>
+        <location filename="configureosc.ui" line="122"/>
         <source>Channel number calculator</source>
         <translation>Calcolatore numero di canale</translation>
     </message>
     <message>
-        <location filename="configureosc.ui" line="96"/>
+        <location filename="configureosc.ui" line="130"/>
         <source>OSC path</source>
         <translation>Percorso OSC</translation>
     </message>
     <message>
-        <location filename="configureosc.ui" line="106"/>
+        <location filename="configureosc.ui" line="140"/>
         <source>Channel number</source>
         <translation>Numero di canale</translation>
     </message>
     <message>
-        <location filename="configureosc.cpp" line="83"/>
+        <location filename="configureosc.cpp" line="88"/>
         <source>Inputs</source>
         <translation>Ingressi</translation>
     </message>
     <message>
-        <location filename="configureosc.cpp" line="89"/>
+        <location filename="configureosc.cpp" line="94"/>
         <source>Outputs</source>
         <translation>Uscite</translation>
     </message>
     <message>
-        <location filename="configureosc.cpp" line="171"/>
+        <location filename="configureosc.cpp" line="176"/>
         <source>Invalid IP</source>
         <translation>Indirizzo IP non valido</translation>
     </message>
     <message>
-        <location filename="configureosc.cpp" line="171"/>
+        <location filename="configureosc.cpp" line="176"/>
         <source>%1 is not a valid IP.
 Please fix it before confirming.</source>
         <translation>%1 non è un indirizzo IP valido.
@@ -80,39 +85,39 @@ E&apos; necessario sistemare prima di confermare.</translation>
 <context>
     <name>OSCPlugin</name>
     <message>
-        <location filename="oscplugin.cpp" line="91"/>
+        <location filename="oscplugin.cpp" line="96"/>
         <source>This plugin provides input for devices supporting the OSC transmission protocol.</source>
         <translation>Questa plugin permette la ricezione di segnale da dispositivi che supportano il protocollo OSC.</translation>
     </message>
     <message>
-        <location filename="oscplugin.cpp" line="142"/>
-        <location filename="oscplugin.cpp" line="276"/>
+        <location filename="oscplugin.cpp" line="147"/>
+        <location filename="oscplugin.cpp" line="280"/>
         <source>Status: Not open</source>
         <translation>Stato: Non aperto</translation>
     </message>
     <message>
-        <location filename="oscplugin.cpp" line="145"/>
-        <location filename="oscplugin.cpp" line="279"/>
+        <location filename="oscplugin.cpp" line="150"/>
+        <location filename="oscplugin.cpp" line="283"/>
         <source>Status: Open</source>
         <translation>Stato: Aperto</translation>
     </message>
     <message>
-        <location filename="oscplugin.cpp" line="147"/>
+        <location filename="oscplugin.cpp" line="152"/>
         <source>Packets sent: </source>
         <translation>Pacchetti inviati: </translation>
     </message>
     <message>
-        <location filename="oscplugin.cpp" line="281"/>
+        <location filename="oscplugin.cpp" line="285"/>
         <source>Packets received: </source>
         <translation>Pacchetti ricevuti: </translation>
     </message>
     <message>
-        <location filename="oscplugin.cpp" line="138"/>
+        <location filename="oscplugin.cpp" line="143"/>
         <source>Output</source>
         <translation>Uscita</translation>
     </message>
     <message>
-        <location filename="oscplugin.cpp" line="272"/>
+        <location filename="oscplugin.cpp" line="276"/>
         <source>Input</source>
         <translation>Ingresso</translation>
     </message>
