@@ -28,10 +28,12 @@
 #include "functionmanager.h"
 #include "fixturemanager.h"
 #include "qlcfixturemode.h"
+#include "qlccapability.h"
 #include "fixtureutils.h"
 #include "mainviewdmx.h"
 #include "mainview2d.h"
 #include "mainview3d.h"
+#include "qlcchannel.h"
 #include "tardis.h"
 #include "app.h"
 #include "doc.h"
@@ -222,6 +224,16 @@ QString ContextManager::currentContext() const
     return m_view->rootObject()->property("currentContext").toString();
 }
 
+MainView2D *ContextManager::get2DView()
+{
+    return m_2DView;
+}
+
+MainView3D *ContextManager::get3DView()
+{
+    return m_3DView;
+}
+
 QVector3D ContextManager::environmentSize() const
 {
     return m_monProps->gridSize();
@@ -239,9 +251,9 @@ void ContextManager::setEnvironmentSize(QVector3D environmentSize)
         m_2DView->setGridSize(environmentSize);
     if (m_3DView->isEnabled())
     {
-        for(Fixture *fixture : m_doc->fixtures()) // C++11
+        for (Fixture *fixture : m_doc->fixtures()) // C++11
         {
-            for (quint32 subID : m_monProps->fixtureIDList(fixture->id()))
+            for (quint32 &subID : m_monProps->fixtureIDList(fixture->id()))
             {
                 quint16 headIndex = m_monProps->fixtureHeadIndex(subID);
                 quint16 linkedIndex = m_monProps->fixtureLinkedIndex(subID);
@@ -291,7 +303,7 @@ void ContextManager::setPositionPickPoint(QVector3D point)
                       point.y(),
                       point.z() + m_monProps->gridSize().z() / 2);
 
-    for (quint32 itemID : m_selectedFixtures)
+    for (quint32 &itemID : m_selectedFixtures)
     {
         quint32 fxID = FixtureUtils::itemFixtureID(itemID);
 
@@ -344,7 +356,7 @@ void ContextManager::setPositionPickPoint(QVector3D point)
                 panDeg = 90.0 + (90.0 - panDeg);
             else if (!xLeft && !zBack)
                 panDeg = 180.0 + panDeg;
-            else if(!xLeft && zBack)
+            else if (!xLeft && zBack)
                 panDeg = 270.0 + (90.0 - panDeg);
 
             if (itemFlags & MonitorProperties::InvertedPanFlag)
@@ -357,7 +369,7 @@ void ContextManager::setPositionPickPoint(QVector3D point)
             qDebug() << "Fixture" << fxID << "pan degrees:" << panDeg;
 
             QList<SceneValue> svList = fixture->positionToValues(QLCChannel::Pan, panDeg);
-            for (SceneValue posSv : svList)
+            for (SceneValue &posSv : svList)
             {
                 if (m_editingEnabled == false)
                     setDumpValue(posSv.fxi, posSv.channel, posSv.value);
@@ -391,7 +403,7 @@ void ContextManager::setPositionPickPoint(QVector3D point)
             qDebug() << "Fixture" << fxID << "tilt degrees:" << tiltDeg;
 
             QList<SceneValue> svList = fixture->positionToValues(QLCChannel::Tilt, tiltDeg);
-            for (SceneValue posSv : svList)
+            for (SceneValue &posSv : svList)
             {
                 if (m_editingEnabled == false)
                     setDumpValue(posSv.fxi, posSv.channel, posSv.value);
@@ -408,7 +420,7 @@ void ContextManager::resetContexts()
 {
     m_channelsMap.clear();
     resetDumpValues();
-    for (quint32 itemID : m_selectedFixtures)
+    for (quint32 &itemID : m_selectedFixtures)
         setFixtureSelection(itemID, -1, false);
 
     m_selectedFixtures.clear();
@@ -533,6 +545,7 @@ void ContextManager::setItemSelection(quint32 itemID, bool enable, int keyModifi
     {
         setFixtureSelection(itemID, -1, enable);
     }
+    m_fixtureManager->setItemRoleData(itemID, enable ? 2 : 0, TreeModel::IsSelectedRole);
 }
 
 void ContextManager::setFixtureSelection(quint32 itemID, int headIndex, bool enable)
@@ -570,12 +583,14 @@ void ContextManager::setFixtureSelection(quint32 itemID, int headIndex, bool ena
     if (fixture == nullptr)
         return;
 
+    m_fixtureManager->setItemRoleData(itemID, enable ? 2 : 0, TreeModel::IsSelectedRole);
+
     if (m_DMXView->isEnabled())
         m_DMXView->updateFixtureSelection(fixtureID, enable);
 
     if (headIndex == -1 && fixture->type() == QLCFixtureDef::Dimmer)
     {
-        for (quint32 subID : m_monProps->fixtureIDList(fixtureID))
+        for (quint32 &subID : m_monProps->fixtureIDList(fixtureID))
         {
             quint16 hIndex = m_monProps->fixtureHeadIndex(subID);
             quint16 lIndex = m_monProps->fixtureLinkedIndex(subID);
@@ -600,7 +615,7 @@ void ContextManager::setFixtureSelection(quint32 itemID, int headIndex, bool ena
     }
 
     QMultiHash<int, SceneValue> channels = m_fixtureManager->getFixtureCapabilities(itemID, headIndex, enable);
-    if(channels.keys().isEmpty())
+    if (channels.keys().isEmpty())
         return;
 
     qDebug() << "[ContextManager] found" << channels.keys().count() << "capabilities";
@@ -609,7 +624,7 @@ void ContextManager::setFixtureSelection(quint32 itemID, int headIndex, bool ena
 #else
     QMultiHashIterator<int, SceneValue> it(channels);
 #endif
-    while(it.hasNext())
+    while (it.hasNext())
     {
         it.next();
         quint32 chType = it.key();
@@ -630,7 +645,7 @@ void ContextManager::setFixtureSelection(quint32 itemID, int headIndex, bool ena
 
 void ContextManager::setFixtureIDSelection(quint32 fixtureID, bool enable)
 {
-    for (quint32 subID : m_monProps->fixtureIDList(fixtureID))
+    for (quint32 &subID : m_monProps->fixtureIDList(fixtureID))
     {
         quint16 headIndex = m_monProps->fixtureHeadIndex(subID);
         quint16 linkedIndex = m_monProps->fixtureLinkedIndex(subID);
@@ -650,7 +665,7 @@ void ContextManager::resetFixtureSelection()
         if (fixture == nullptr)
             continue;
 
-        for (quint32 subID : m_monProps->fixtureIDList(fixture->id()))
+        for (quint32 &subID : m_monProps->fixtureIDList(fixture->id()))
         {
             quint16 headIndex = m_monProps->fixtureHeadIndex(subID);
             quint16 linkedIndex = m_monProps->fixtureLinkedIndex(subID);
@@ -665,9 +680,9 @@ void ContextManager::toggleFixturesSelection()
     bool selectAll = true;
     int visibleCount = 0;
 
-    for (quint32 fixtureID : m_monProps->fixtureItemsID())
+    for (quint32 &fixtureID : m_monProps->fixtureItemsID())
     {
-        for (quint32 subID : m_monProps->fixtureIDList(fixtureID))
+        for (quint32 &subID : m_monProps->fixtureIDList(fixtureID))
         {
             quint16 headIndex = m_monProps->fixtureHeadIndex(subID);
             quint16 linkedIndex = m_monProps->fixtureLinkedIndex(subID);
@@ -685,7 +700,7 @@ void ContextManager::toggleFixturesSelection()
         if (fixture == nullptr)
             continue;
 
-        for (quint32 subID : m_monProps->fixtureIDList(fixture->id()))
+        for (quint32 &subID : m_monProps->fixtureIDList(fixture->id()))
         {
             quint16 headIndex = m_monProps->fixtureHeadIndex(subID);
             quint16 linkedIndex = m_monProps->fixtureLinkedIndex(subID);
@@ -714,7 +729,7 @@ void ContextManager::setRectangleSelection(qreal x, qreal y, qreal width, qreal
 QVariantList ContextManager::selectedFixtureAddress()
 {
     QVariantList addresses;
-    for (quint32 itemID : m_selectedFixtures)
+    for (quint32 &itemID : m_selectedFixtures)
     {
         quint32 fxID = FixtureUtils::itemFixtureID(itemID);
         Fixture *fixture = m_doc->fixture(fxID);
@@ -737,7 +752,7 @@ QVariantList ContextManager::selectedFixtureAddress()
 QVariantList ContextManager::selectedFixtureIDVariantList()
 {
     QVariantList list;
-    for (quint32 itemID : m_selectedFixtures)
+    for (quint32 &itemID : m_selectedFixtures)
     {
         quint32 fxID = FixtureUtils::itemFixtureID(itemID);
         list.append(fxID);
@@ -775,7 +790,7 @@ void ContextManager::setFixturePosition(quint32 itemID, qreal x, qreal y, qreal
 
 void ContextManager::setFixturesOffset(qreal x, qreal y)
 {
-    for (quint32 itemID : m_selectedFixtures)
+    for (quint32 &itemID : m_selectedFixtures)
     {
         quint32 fxID = FixtureUtils::itemFixtureID(itemID);
         quint16 headIndex = FixtureUtils::itemHeadIndex(itemID);
@@ -844,7 +859,7 @@ void ContextManager::setFixturesPosition(QVector3D position)
     else
     {
         // relative position change
-        for (quint32 itemID : m_selectedFixtures)
+        for (quint32 &itemID : m_selectedFixtures)
         {
             quint32 fxID = FixtureUtils::itemFixtureID(itemID);
             quint16 headIndex = FixtureUtils::itemHeadIndex(itemID);
@@ -865,7 +880,7 @@ void ContextManager::setFixturesPosition(QVector3D position)
 void ContextManager::setFixturesGelColor(QColor color)
 {
     QByteArray ba;
-    for (quint32 itemID : m_selectedFixtures)
+    for (quint32 &itemID : m_selectedFixtures)
     {
         quint32 fxID = FixtureUtils::itemFixtureID(itemID);
         quint16 headIndex = FixtureUtils::itemHeadIndex(itemID);
@@ -891,7 +906,7 @@ void ContextManager::setFixturesAlignment(int alignment)
     quint16 firstLinkedIndex = FixtureUtils::itemLinkedIndex(m_selectedFixtures.first());
     QVector3D firstPos = m_monProps->fixturePosition(firstFxID, firstHeadIndex, firstLinkedIndex);
 
-    for (quint32 itemID : m_selectedFixtures)
+    for (quint32 &itemID : m_selectedFixtures)
     {
         quint32 fxID = FixtureUtils::itemFixtureID(itemID);
         quint16 headIndex = FixtureUtils::itemHeadIndex(itemID);
@@ -925,7 +940,7 @@ void ContextManager::setFixturesDistribution(int direction)
      * 2- sort the fixture IDs from the leftmost/topmost item
      * 3- detect the minimum and maximum items position
      */
-    for (quint32 itemID : m_selectedFixtures)
+    for (quint32 &itemID : m_selectedFixtures)
     {
         quint32 fxID = FixtureUtils::itemFixtureID(itemID);
         quint16 headIndex = FixtureUtils::itemHeadIndex(itemID);
@@ -1056,7 +1071,7 @@ void ContextManager::setLinkedFixture(quint32 itemID)
             return;
 
         // 1- iterate through Fixture subitems to find a new linked index
-        for (quint32 subID : m_monProps->fixtureIDList(fixtureID))
+        for (quint32 &subID : m_monProps->fixtureIDList(fixtureID))
         {
             quint16 hIdx = m_monProps->fixtureHeadIndex(subID);
             quint16 lIdx = m_monProps->fixtureLinkedIndex(subID);
@@ -1075,7 +1090,7 @@ void ContextManager::setLinkedFixture(quint32 itemID)
             pos.setY(pos.y() + phy.height() + 50);
 
         // 3- add the new item to monitor properties
-        QString newName = QString("%1 (%2 %3)").arg(fixture->name()).arg(tr("linked")).arg(newIndex);
+        QString newName = QString("%1 (%2 %3)").arg(fixture->name(), tr("linked")).arg(newIndex);
         m_monProps->setFixturePosition(fixtureID, headIndex, newIndex, pos);
         m_monProps->setFixtureName(fixtureID, headIndex, newIndex, newName);
 
@@ -1093,7 +1108,7 @@ void ContextManager::setLinkedFixture(quint32 itemID)
 
 void ContextManager::updateFixturesCapabilities()
 {
-    for (quint32 itemID : m_selectedFixtures)
+    for (quint32 &itemID : m_selectedFixtures)
         m_fixtureManager->getFixtureCapabilities(itemID, -1, true);
 }
 
@@ -1115,18 +1130,30 @@ qreal ContextManager::getCurrentValue(int type, bool degrees)
             continue;
 
         qreal chValue = fixture->channelValueAt(sv.channel);
+        qreal divider = ch->controlByte() == QLCChannel::MSB ? 256.0 : 65536.0;
+
+        if (degrees)
+        {
+            QLCFixtureMode *fxMode = fixture->fixtureMode();
+            QLCPhysical phy = fxMode->physical();
+            switch (type)
+            {
+                case QLCChannel::Pan:
+                    chValue = (qreal(phy.focusPanMax()) / divider) * chValue;
+                break;
+                case QLCChannel::Tilt:
+                    chValue = (qreal(phy.focusTiltMax()) / divider) * chValue;
+                break;
+                case QLCChannel::Beam:
+                    chValue = qreal((phy.lensDegreesMax() - phy.lensDegreesMin()) / divider) * chValue;
+                    if (ch->controlByte() == QLCChannel::MSB)
+                        chValue += phy.lensDegreesMin();
+                break;
+            }
+        }
 
         if (ch->controlByte() == QLCChannel::MSB)
         {
-            if (degrees)
-            {
-                QLCFixtureMode *fxMode = fixture->fixtureMode();
-                QLCPhysical phy = fxMode->physical();
-                if (type == QLCChannel::Pan)
-                    chValue = (qreal(phy.focusPanMax()) / 256.0) * chValue;
-                else if (type == QLCChannel::Tilt)
-                    chValue = (qreal(phy.focusTiltMax()) / 256.0) * chValue;
-            }
             if (currMsbValue != -1 && currMsbValue != chValue)
                 return -1;
 
@@ -1134,16 +1161,6 @@ qreal ContextManager::getCurrentValue(int type, bool degrees)
         }
         else if (ch->controlByte() == QLCChannel::LSB)
         {
-            if (degrees)
-            {
-                QLCFixtureMode *fxMode = fixture->fixtureMode();
-                QLCPhysical phy = fxMode->physical();
-                if (type == QLCChannel::Pan)
-                    chValue = (qreal(phy.focusPanMax()) / 65536.0) * chValue;
-                else if (type == QLCChannel::Tilt)
-                    chValue = (qreal(phy.focusTiltMax()) / 65536.0) * chValue;
-            }
-
             if (currLsbValue != -1 && currLsbValue != chValue)
                 return -1;
 
@@ -1152,11 +1169,75 @@ qreal ContextManager::getCurrentValue(int type, bool degrees)
     }
 
     qDebug() << "Channel type" << type << "MSB" << currMsbValue << "LSB" << currLsbValue;
-    currValue = currMsbValue + currLsbValue / 255.0;
+    currValue = currMsbValue + (currLsbValue == -1 ? 0 : currLsbValue);
 
     return currValue;
 }
 
+void ContextManager::getCurrentColors(QQuickItem *item)
+{
+    int rgbDiffCount = 0;
+    int wauvDiffCount = 0;
+    QColor rgbColor;
+    QColor wauvColor;
+
+    for (quint32 &itemID : m_selectedFixtures)
+    {
+        quint32 fxID = FixtureUtils::itemFixtureID(itemID);
+        quint16 headIndex = FixtureUtils::itemHeadIndex(itemID);
+
+        Fixture *fixture = m_doc->fixture(fxID);
+        if (fixture == nullptr)
+            continue;
+
+        QColor itemRgbColor;
+        QColor itemWauvColor;
+
+        QVector <quint32> rgbCh = fixture->rgbChannels(headIndex);
+        if (rgbCh.size() == 3)
+        {
+            itemRgbColor.setRgb(fixture->channelValueAt(rgbCh.at(0)),
+                             fixture->channelValueAt(rgbCh.at(1)),
+                             fixture->channelValueAt(rgbCh.at(2)));
+        }
+
+        QVector <quint32> cmyCh = fixture->cmyChannels(headIndex);
+        if (cmyCh.size() == 3)
+        {
+            itemRgbColor.setCmyk(fixture->channelValueAt(cmyCh.at(0)),
+                              fixture->channelValueAt(cmyCh.at(1)),
+                              fixture->channelValueAt(cmyCh.at(2)), 0);
+        }
+
+        if (rgbDiffCount == 0 || itemRgbColor == rgbColor)
+            rgbColor = itemRgbColor;
+        else
+            rgbDiffCount++;
+
+        quint32 white = fixture->channelNumber(QLCChannel::White, QLCChannel::MSB, headIndex);
+        quint32 amber = fixture->channelNumber(QLCChannel::Amber, QLCChannel::MSB, headIndex);
+        quint32 UV = fixture->channelNumber(QLCChannel::UV, QLCChannel::MSB, headIndex);
+
+        if (white != QLCChannel::invalid())
+            itemWauvColor.setRed(fixture->channelValueAt(white));
+        if (amber != QLCChannel::invalid())
+            itemWauvColor.setGreen(fixture->channelValueAt(amber));
+        if (UV != QLCChannel::invalid())
+            itemWauvColor.setBlue(fixture->channelValueAt(UV));
+
+        if (wauvDiffCount == 0 || itemWauvColor == wauvColor)
+            wauvColor = itemWauvColor;
+        else
+            wauvDiffCount++;
+    }
+
+    QMetaObject::invokeMethod(item, "updateColors",
+                              Q_ARG(QVariant, rgbDiffCount ? false : true),
+                              Q_ARG(QVariant, rgbColor),
+                              Q_ARG(QVariant, wauvDiffCount ? false : true),
+                              Q_ARG(QVariant, wauvColor));
+}
+
 void ContextManager::createFixtureGroup()
 {
     if (m_selectedFixtures.isEmpty())
@@ -1186,26 +1267,31 @@ void ContextManager::setFixturesRotation(QVector3D degrees)
 {
     if (m_selectedFixtures.count() == 1)
     {
-        quint32 fxID = FixtureUtils::itemFixtureID(m_selectedFixtures.first());
-        quint16 headIndex = FixtureUtils::itemHeadIndex(m_selectedFixtures.first());
-        quint16 linkedIndex = FixtureUtils::itemLinkedIndex(m_selectedFixtures.first());
+        quint32 itemID = m_selectedFixtures.first();
+        quint32 fxID = FixtureUtils::itemFixtureID(itemID);
+        quint16 headIndex = FixtureUtils::itemHeadIndex(itemID);
+        quint16 linkedIndex = FixtureUtils::itemLinkedIndex(itemID);
+        QVector3D rotation = m_monProps->fixtureRotation(fxID, headIndex, linkedIndex);
+
+        Tardis::instance()->enqueueAction(Tardis::FixtureSetRotation, itemID, QVariant(rotation), QVariant(degrees));
 
         // absolute rotation change
         m_monProps->setFixtureRotation(fxID, headIndex, linkedIndex, degrees);
         if (m_2DView->isEnabled())
-            m_2DView->updateFixtureRotation(m_selectedFixtures.first(), degrees);
+            m_2DView->updateFixtureRotation(itemID, degrees);
         if (m_3DView->isEnabled())
-            m_3DView->updateFixtureRotation(m_selectedFixtures.first(), degrees);
+            m_3DView->updateFixtureRotation(itemID, degrees);
     }
     else
     {
         // relative rotation change
-        for (quint32 itemID : m_selectedFixtures)
+        for (quint32 &itemID : m_selectedFixtures)
         {
             quint32 fxID = FixtureUtils::itemFixtureID(itemID);
             quint16 headIndex = FixtureUtils::itemHeadIndex(itemID);
             quint16 linkedIndex = FixtureUtils::itemLinkedIndex(itemID);
-            QVector3D newRot = m_monProps->fixtureRotation(fxID, headIndex, linkedIndex) + degrees;
+            QVector3D rotation = m_monProps->fixtureRotation(fxID, headIndex, linkedIndex);
+            QVector3D newRot = rotation + degrees;
 
             // normalize back to a 0-359 range
             if (newRot.x() < 0) newRot.setX(newRot.x() + 360);
@@ -1217,6 +1303,8 @@ void ContextManager::setFixturesRotation(QVector3D degrees)
             if (newRot.z() < 0) newRot.setZ(newRot.z() + 360);
             else if (newRot.z() >= 360) newRot.setZ(newRot.z() - 360);
 
+            Tardis::instance()->enqueueAction(Tardis::FixtureSetRotation, itemID, QVariant(rotation), QVariant(newRot));
+
             m_monProps->setFixtureRotation(fxID, headIndex, linkedIndex, newRot);
             if (m_2DView->isEnabled())
                 m_2DView->updateFixtureRotation(itemID, newRot);
@@ -1228,6 +1316,23 @@ void ContextManager::setFixturesRotation(QVector3D degrees)
     emit fixturesRotationChanged();
 }
 
+void ContextManager::setFixtureRotation(quint32 itemID, QVector3D degrees)
+{
+    quint32 fxID = FixtureUtils::itemFixtureID(itemID);
+    quint16 headIndex = FixtureUtils::itemHeadIndex(itemID);
+    quint16 linkedIndex = FixtureUtils::itemLinkedIndex(itemID);
+    QVector3D rotation = m_monProps->fixtureRotation(fxID, headIndex, linkedIndex);
+
+    Tardis::instance()->enqueueAction(Tardis::FixtureSetRotation, itemID, QVariant(rotation), QVariant(degrees));
+
+    // absolute rotation change
+    m_monProps->setFixtureRotation(fxID, headIndex, linkedIndex, degrees);
+    if (m_2DView->isEnabled())
+        m_2DView->updateFixtureRotation(itemID, degrees);
+    if (m_3DView->isEnabled())
+        m_3DView->updateFixtureRotation(itemID, degrees);
+}
+
 void ContextManager::setFixtureGroupSelection(quint32 id, bool enable, bool isUniverse)
 {
     if (isUniverse)
@@ -1236,7 +1341,7 @@ void ContextManager::setFixtureGroupSelection(quint32 id, bool enable, bool isUn
         {
             if (fixture->universe() == id)
             {
-                for (quint32 subID : m_monProps->fixtureIDList(fixture->id()))
+                for (quint32 &subID : m_monProps->fixtureIDList(fixture->id()))
                 {
                     quint16 headIndex = m_monProps->fixtureHeadIndex(subID);
                     quint16 linkedIndex = m_monProps->fixtureLinkedIndex(subID);
@@ -1252,13 +1357,13 @@ void ContextManager::setFixtureGroupSelection(quint32 id, bool enable, bool isUn
         if (group == nullptr)
             return;
 
-        for (quint32 fxID : group->fixtureList())
+        for (quint32 &fxID : group->fixtureList())
         {
             Fixture *fixture = m_doc->fixture(fxID);
             if (fixture == nullptr)
                 continue;
 
-            for (quint32 subID : m_monProps->fixtureIDList(fxID))
+            for (quint32 &subID : m_monProps->fixtureIDList(fxID))
             {
                 quint16 headIndex = m_monProps->fixtureHeadIndex(subID);
                 quint16 linkedIndex = m_monProps->fixtureLinkedIndex(subID);
@@ -1276,6 +1381,8 @@ void ContextManager::slotNewFixtureCreated(quint32 fxID, qreal x, qreal y, qreal
 
     qDebug() << "[ContextManager] New fixture created" << fxID;
 
+    if (m_uniGridView->isEnabled())
+        m_monProps->setFixturePosition(fxID, 0, 0, QVector3D(0, 0, 0));
     if (m_DMXView->isEnabled())
         m_DMXView->createFixtureItem(fxID);
     if (m_2DView->isEnabled())
@@ -1392,21 +1499,31 @@ void ContextManager::setPositionValue(int type, int degrees, bool isRelative)
     }
 }
 
-void ContextManager::setBeamDegrees(float degrees)
+void ContextManager::setPositionCenter()
+{
+    setChannelValueByType((int)QLCChannel::Pan, 127);
+    setChannelValueByType((int)QLCChannel::Tilt, 127);
+}
+
+void ContextManager::setBeamDegrees(float degrees, bool isRelative)
 {
     // list to keep track of the already processed Fixture IDs
     QList<quint32>fxIDs;
     QList<SceneValue> typeList = m_channelsMap.values(QLCChannel::Beam);
 
-    for (SceneValue sv : typeList)
+    for (SceneValue &sv : typeList)
     {
         if (fxIDs.contains(sv.fxi) == true)
             continue;
 
         fxIDs.append(sv.fxi);
 
-        QList<SceneValue> svList = m_fixtureManager->getFixtureZoom(sv.fxi, degrees);
-        for (SceneValue zSv : svList)
+        Fixture *fixture = m_doc->fixture(sv.fxi);
+        if (fixture == nullptr || fixture->fixtureMode() == nullptr)
+            continue;
+
+        QList<SceneValue> svList = fixture->zoomToValues(degrees, isRelative);
+        for (SceneValue &zSv : svList)
         {
             if (m_editingEnabled == false)
                 setDumpValue(zSv.fxi, zSv.channel, zSv.value);
@@ -1416,9 +1533,45 @@ void ContextManager::setBeamDegrees(float degrees)
     }
 }
 
+void ContextManager::highlightFixtureSelection()
+{
+    setChannelValueByType((int)QLCChannel::Red, UCHAR_MAX);
+    setChannelValueByType((int)QLCChannel::Green, UCHAR_MAX);
+    setChannelValueByType((int)QLCChannel::Blue, UCHAR_MAX);
+    setChannelValueByType((int)QLCChannel::White, UCHAR_MAX);
+
+    setChannelValueByType((int)QLCChannel::Intensity, UCHAR_MAX);
+
+    // search for shutter open and lamp on
+    for (quint32 &itemID : m_selectedFixtures)
+    {
+        quint32 fxID = FixtureUtils::itemFixtureID(itemID);
+        Fixture *fixture = m_doc->fixture(fxID);
+        if (fixture == nullptr)
+            continue;
+
+        for (quint32 i = 0; i < fixture->channels(); i++)
+        {
+            const QLCChannel *channel = fixture->channel(i);
+            for (QLCCapability *cap : channel->capabilities())
+            {
+                if (cap->preset() == QLCCapability::ShutterOpen ||
+                    cap->preset() == QLCCapability::LampOn)
+                {
+                    if (m_editingEnabled == false)
+                        setDumpValue(fxID, i, cap->middle());
+                    else
+                        m_functionManager->setChannelValue(fxID, i, cap->middle());
+                    break;
+                }
+            }
+        }
+    }
+}
+
 void ContextManager::setChannelValues(QList<SceneValue> values)
 {
-    for (SceneValue sv : values)
+    for (SceneValue &sv : values)
     {
         if (m_editingEnabled == false)
             setDumpValue(sv.fxi, sv.channel, sv.value);
@@ -1429,7 +1582,7 @@ void ContextManager::setChannelValues(QList<SceneValue> values)
 
 void ContextManager::slotPresetChanged(const QLCChannel *channel, quint8 value)
 {
-    for (quint32 itemID : m_selectedFixtures)
+    for (quint32 &itemID : m_selectedFixtures)
     {
         quint32 fixtureID = FixtureUtils::itemFixtureID(itemID);
         Fixture *fixture = m_doc->fixture(fixtureID);
@@ -1475,6 +1628,9 @@ void ContextManager::slotUniverseWritten(quint32 idx, const QByteArray &ua)
 
 void ContextManager::slotFunctionEditingChanged(bool status)
 {
+    if (status == m_editingEnabled)
+        return;
+
     resetFixtureSelection();
     m_editingEnabled = status;
 }
@@ -1492,7 +1648,7 @@ void ContextManager::setDumpValue(quint32 fxID, quint32 channel, uchar value, bo
     currentVal.setValue(SceneValue(fxID, channel, currDmxValue));
     newVal.setValue(sValue);
 
-    if (currentVal != newVal || value != currDmxValue)
+    //if (currentVal != newVal || value != currDmxValue)
     {
         if (output)
         {
@@ -1592,7 +1748,7 @@ void ContextManager::dumpDmxChannels(quint32 sceneID, quint32 mask)
 
 void ContextManager::resetDumpValues()
 {
-    for (SceneValue sv : m_dumpValues)
+    for (SceneValue &sv : m_dumpValues)
         m_source->unset(sv.fxi, sv.channel);
 
     m_source->unsetAll();
@@ -1608,3 +1764,4 @@ GenericDMXSource *ContextManager::dmxSource() const
 {
     return m_source;
 }
+
