@@ -79,6 +79,9 @@ public:
     /** Return the currently active context */
     QString currentContext() const;
 
+    MainView2D *get2DView();
+    MainView3D *get3DView();
+
     /** Get/Set the environment width/height/depth size */
     QVector3D environmentSize() const;
     void setEnvironmentSize(QVector3D environmentSize);
@@ -217,11 +220,15 @@ public:
      *  Returns -1 in case of mixed values */
     Q_INVOKABLE qreal getCurrentValue(int type, bool degrees);
 
+    /** Get the RGB color of the current fixture selection */
+    Q_INVOKABLE void getCurrentColors(QQuickItem *item);
+
     Q_INVOKABLE void createFixtureGroup();
 
     /** Set/Get the rotation of the currently selected fixtures */
     QVector3D fixturesRotation() const;
     void setFixturesRotation(QVector3D degrees);
+    void setFixtureRotation(quint32 itemID, QVector3D degrees);
 
     /** Select/Deselect all the fixtures of the Group/Universe with the provided $id */
     Q_INVOKABLE void setFixtureGroupSelection(quint32 id, bool enable, bool isUniverse);
@@ -233,8 +240,13 @@ public:
     /** Set a Pan/Tilt position in degrees */
     Q_INVOKABLE void setPositionValue(int type, int degrees, bool isRelative);
 
+    /** Set Pan/Tilt values at half position */
+    Q_INVOKABLE void setPositionCenter();
+
     /** Set a zoom channel in degrees */
-    Q_INVOKABLE void setBeamDegrees(float degrees);
+    Q_INVOKABLE void setBeamDegrees(float degrees, bool isRelative);
+
+    Q_INVOKABLE void highlightFixtureSelection();
 
     void setChannelValues(QList<SceneValue> values);
 
