@@ -38,6 +38,7 @@
 
 #define INPUT_SLIDER_CONTROL_ID     0
 #define INPUT_SLIDER_RESET_ID       1
+#define INPUT_SLIDER_FLASH_ID       2
 
 VCSlider::VCSlider(Doc *doc, QObject *parent)
     : VCWidget(doc, parent)
@@ -64,12 +65,14 @@ VCSlider::VCSlider(Doc *doc, QObject *parent)
     , m_controlledAttributeId(Function::invalidAttributeId())
     , m_attributeMinValue(0)
     , m_attributeMaxValue(UCHAR_MAX)
+    , m_adjustFlashEnabled(false)
 {
     setType(VCWidget::SliderWidget);
     setSliderMode(Adjust);
 
     registerExternalControl(INPUT_SLIDER_CONTROL_ID, tr("Slider Control"), false);
     registerExternalControl(INPUT_SLIDER_RESET_ID, tr("Reset Control"), false);
+    registerExternalControl(INPUT_SLIDER_FLASH_ID, tr("Flash Control"), true);
 }
 
 VCSlider::~VCSlider()
@@ -676,7 +679,7 @@ QVariantList VCSlider::clickAndGoPresetsList()
         return prList;
 
     /* Find the first valid channel and return it to QML */
-    for (SceneValue scv : m_levelChannels)
+    for (SceneValue &scv : m_levelChannels)
     {
         Fixture *fixture = m_doc->fixture(scv.fxi);
         if (fixture == nullptr)
@@ -803,7 +806,7 @@ void VCSlider::setControlledFunction(quint32 fid)
         disconnect(current, SIGNAL(attributeChanged(int,qreal)),
                 this, SLOT(slotControlledFunctionAttributeChanged(int,qreal)));
 
-        if(current->isRunning())
+        if (current->isRunning())
         {
             running = true;
             current->stop(functionParent());
@@ -849,7 +852,7 @@ void VCSlider::adjustIntensity(qreal val)
 
     if (sliderMode() == Adjust)
     {
-        Function* function = m_doc->function(m_controlledFunctionId);
+        Function *function = m_doc->function(m_controlledFunctionId);
         if (function == nullptr)
             return;
 
@@ -882,7 +885,7 @@ void VCSlider::slotControlledFunctionStopped(quint32 fid)
         if (m_controlledAttributeIndex == Function::Intensity)
             setValue(0, false, true);
 
-        Function* function = m_doc->function(fid);
+        Function *function = m_doc->function(fid);
         function->releaseAttributeOverride(m_controlledAttributeId);
         m_controlledAttributeId = Function::invalidAttributeId();
     }
@@ -898,7 +901,7 @@ void VCSlider::setControlledAttribute(int attributeIndex)
     if (m_controlledAttributeIndex == attributeIndex)
         return;
 
-    Function* function = m_doc->function(m_controlledFunctionId);
+    Function *function = m_doc->function(m_controlledFunctionId);
     if (function == nullptr || attributeIndex >= function->attributes().count())
         return;
 
@@ -944,15 +947,46 @@ void VCSlider::adjustFunctionAttribute(Function *f, qreal value)
         f->adjustAttribute(value, m_controlledAttributeId);
 }
 
+bool VCSlider::adjustFlashEnabled() const
+{
+    return m_adjustFlashEnabled;
+}
+
+void VCSlider::setAdjustFlashEnabled(bool enable)
+{
+    if (enable == m_adjustFlashEnabled)
+        return;
+
+    m_adjustFlashEnabled = enable;
+    emit adjustFlashEnabledChanged(enable);
+}
+
+void VCSlider::flashFunction(bool on)
+{
+    Function *function = m_doc->function(m_controlledFunctionId);
+    if (function == nullptr)
+        return;
+
+    if (on)
+    {
+        if (m_controlledAttributeId == Function::invalidAttributeId())
+            m_adjustFlashPreviousValue = 0;
+        else
+            m_adjustFlashPreviousValue = function->getAttributeValue(m_controlledAttributeIndex);
+    }
+
+    adjustFunctionAttribute(function, on ? 1.0 : m_adjustFlashPreviousValue);
+}
+
 QStringList VCSlider::availableAttributes() const
 {
     QStringList list;
 
-    Function* function = m_doc->function(m_controlledFunctionId);
+    Function *function = m_doc->function(m_controlledFunctionId);
     if (function == nullptr)
         return list;
 
-    for (Attribute attr : function->attributes())
+    for (Attribute &attr : function->attributes())
         list << attr.m_name;
 
     return list;
@@ -1029,7 +1063,7 @@ void VCSlider::writeDMXLevel(MasterTimer* timer, QList<Universe *> universes)
 
     if (clickAndGoType() == CnGColors)
     {
-        float f = SCALE(float(m_value), rangeLowLimit(), rangeHighLimit(), 0.0, 200.0);
+        float f = SCALE(float(modLevel), rangeLowLimit(), rangeHighLimit(), 0.0, 200.0);
 
         if ((uchar)f != 0)
         {
@@ -1053,7 +1087,7 @@ void VCSlider::writeDMXLevel(MasterTimer* timer, QList<Universe *> universes)
         bool mixedDMXlevels = false;
         int monitorSliderValue = -1;
 
-        for (SceneValue scv : m_levelChannels)
+        for (SceneValue &scv : m_levelChannels)
         {
             Fixture* fxi = m_doc->fixture(scv.fxi);
             if (fxi != nullptr)
@@ -1108,7 +1142,7 @@ void VCSlider::writeDMXLevel(MasterTimer* timer, QList<Universe *> universes)
 
     if (m_levelValueChanged)
     {
-        for (SceneValue scv : m_levelChannels)
+        for (SceneValue &scv : m_levelChannels)
         {
             Fixture* fxi = m_doc->fixture(scv.fxi);
             if (fxi == nullptr)
@@ -1136,6 +1170,10 @@ void VCSlider::writeDMXLevel(MasterTimer* timer, QList<Universe *> universes)
             if (m_isOverriding)
                 fc->addFlag(FadeChannel::Override);
 
+            // request to autoremove LTP channels when set
+            if (! (chType & FadeChannel::Intensity))
+                fc->addFlag(FadeChannel::AutoRemove);
+
             if (chType & FadeChannel::Intensity && clickAndGoType() == CnGColors)
             {
                 const QLCChannel *qlcch = fxi->channel(scv.channel);
@@ -1176,7 +1214,7 @@ void VCSlider::writeDMXAdjust(MasterTimer* timer, QList<Universe *> ua)
     if (m_adjustChangeCounter == 0)
         return;
 
-    Function* function = m_doc->function(m_controlledFunctionId);
+    Function *function = m_doc->function(m_controlledFunctionId);
     if (function == nullptr)
         return;
 
@@ -1233,15 +1271,22 @@ void VCSlider::updateFeedback()
 
 void VCSlider::slotInputValueChanged(quint8 id, uchar value)
 {
+    int scaledValue = SCALE(float(value), float(0), float(UCHAR_MAX),
+            float(rangeLowLimit()),
+            float(rangeHighLimit()));
+
     switch (id)
     {
         case INPUT_SLIDER_CONTROL_ID:
-            setValue(value, true, false);
+            setValue(scaledValue, true, false);
         break;
         case INPUT_SLIDER_RESET_ID:
             if (value)
                 setIsOverriding(false);
         break;
+        case INPUT_SLIDER_FLASH_ID:
+            flashFunction(value ? true : false);
+        break;
     }
 }
 
@@ -1323,6 +1368,11 @@ bool VCSlider::loadXML(QXmlStreamReader &root)
         {
             loadXMLAdjust(root);
         }
+        else if (root.name() == KXMLQLCVCSliderFunctionFlash)
+        {
+            setAdjustFlashEnabled(true);
+            loadXMLSources(root, INPUT_SLIDER_FLASH_ID);
+        }
         else if (root.name() == KXMLQLCVCSliderPlayback) // LEGACY
         {
             loadXMLLegacyPlayback(root);
@@ -1451,6 +1501,11 @@ bool VCSlider::loadXMLLegacyPlayback(QXmlStreamReader &pb_root)
             setControlledFunction(pb_root.readElementText().toUInt());
             setControlledAttribute(Function::Intensity);
         }
+        else if (pb_root.name() == KXMLQLCVCSliderFunctionFlash)
+        {
+            setAdjustFlashEnabled(true);
+            loadXMLSources(pb_root, INPUT_SLIDER_FLASH_ID);
+        }
         else
         {
             qWarning() << Q_FUNC_INFO << "Unknown slider playback tag:" << pb_root.name().toString();
@@ -1524,7 +1579,7 @@ bool VCSlider::saveXML(QXmlStreamWriter *doc)
         doc->writeAttribute(KXMLQLCVCSliderLevelValue, QString::number(value()));
 
     /* Level channels */
-    for (SceneValue scv : m_levelChannels)
+    for (SceneValue &scv : m_levelChannels)
     {
         doc->writeStartElement(KXMLQLCVCSliderChannel);
         doc->writeAttribute(KXMLQLCVCSliderChannelFixture, QString::number(scv.fxi));
@@ -1545,6 +1600,13 @@ bool VCSlider::saveXML(QXmlStreamWriter *doc)
         doc->writeAttribute(KXMLQLCVCSliderControlledFunction, QString::number(controlledFunction()));
         /* End the <Adjust> tag */
         doc->writeEndElement();
+
+        if (adjustFlashEnabled())
+        {
+            //doc->writeStartElement(KXMLQLCVCSliderFunctionFlash);
+            saveXMLInputControl(doc, INPUT_SLIDER_FLASH_ID, KXMLQLCVCSliderFunctionFlash);
+            //doc->writeEndElement();
+        }
     }
 
     /* End the <Slider> tag */
