@@ -3,7 +3,7 @@
 # requires Python LXML (sudo apt-get install python-lxml)
 #
 # When adding new fixtures, regenerate the fixtures map with:
-# scripts/fixtures-tool.py --validate --map
+# ./scripts/fixtures-tool.py --validate --map
 #
 
 import sys
@@ -156,7 +156,7 @@ def update_fixture(path, filename, destpath):
             fineWord = ""
 
             # Modes have a <Channel> tag too, but they don't have a name
-            if not 'Name' in channel.attrib:
+            if 'Name' not in channel.attrib:
                 continue
 
             name = channel.attrib['Name']
@@ -242,18 +242,22 @@ def update_fixture(path, filename, destpath):
 
     newfile = os.path.join(destpath, filename)
     xmlFile = open(newfile, "w")
-    xmlFile.write(etree.tostring(root, pretty_print=True, xml_declaration=True, encoding="UTF-8", doctype="<!DOCTYPE FixtureDefinition>"))
+    if (sys.version_info >= (3, 0)):
+        xmlFile.write(etree.tostring(root, pretty_print=True, xml_declaration=True, encoding="UTF-8", doctype="<!DOCTYPE FixtureDefinition>").decode('utf8'))
+    else:
+        # python 2.x
+        xmlFile.write(etree.tostring(root, pretty_print=True, xml_declaration=True, encoding="UTF-8", doctype="<!DOCTYPE FixtureDefinition>"))
     xmlFile.close()
 
     return fxSingleCapCount
 
-def check_physical(absname, node, hasPan, hasTilt):
-    errNum = 0
+def check_physical(absname, node, hasPan, hasTilt, hasZoom, errNum):
     phy_tag = node.find('{' + namespace + '}Physical')
 
     if phy_tag is not None:
 
         dim_tag = phy_tag.find('{' + namespace + '}Dimensions')
+        lens_tag = phy_tag.find('{' + namespace + '}Lens')
         focus_tag = phy_tag.find('{' + namespace + '}Focus')
         tech_tag = phy_tag.find('{' + namespace + '}Technical')
 
@@ -262,6 +266,8 @@ def check_physical(absname, node, hasPan, hasTilt):
         depth = int(dim_tag.attrib.get('Depth', 0))
         panDeg = int(focus_tag.attrib.get('PanMax', 0))
         tiltDeg = int(focus_tag.attrib.get('TiltMax', 0))
+        zoomMinDeg = float(lens_tag.attrib.get('DegreesMin', 0))
+        zoomMaxDeg = float(lens_tag.attrib.get('DegreesMax', 0))
 
         if width == 0 or height == 0 or depth == 0:
             print(absname + ": Invalid physical dimensions detected")
@@ -275,6 +281,10 @@ def check_physical(absname, node, hasPan, hasTilt):
             print(absname + ": Invalid TILT degrees")
             errNum += 1
 
+        if hasZoom and (zoomMinDeg == 0 or zoomMaxDeg == 0):
+            print(absname + ": Invalid ZOOM degrees")
+            errNum += 1
+
         if tech_tag is not None:
             power = int(tech_tag.attrib.get('PowerConsumption', 0))
             if power == 0:
@@ -284,25 +294,48 @@ def check_physical(absname, node, hasPan, hasTilt):
     return errNum
 
 ###########################################################################################
-# validate_fixture
+# getDefinitionVersion
 #
-# Check the syntax of a definition and reports errors if found
+# Get the version with which the definition was created
 #
-# path: the source path with the fixtures to validate
-# filename: the relative file name
+# xmlObj The fixture XML object
 ###########################################################################################
 
-def validate_fixture(path, filename):
-    absname = os.path.join(path, filename)
-    parser = etree.XMLParser(ns_clean=True, recover=True)
-    xmlObj = etree.parse(absname, parser=parser)
-    root = xmlObj.getroot()
-
+def getDefinitionVersion(xmlObj):
     global namespace
-    errNum = 0
-    hasPan = False
-    hasTilt = False
-    needSave = False
+    root = xmlObj.getroot()
+    qlc_version = 0
+
+    creator_tag = root.find('{' + namespace + '}Creator')
+
+    if creator_tag is None:
+        print("Creator tag not found")
+    else:
+        version_tag = creator_tag.find('{' + namespace + '}Version')
+
+        numversion_tok = re.findall('\d+', version_tag.text)
+        #print("Definition version: " + version_tag.text)
+
+        # extract a unified number from the QLC version string
+        if len(numversion_tok) == 3:
+            qlc_version = (int(numversion_tok[0]) * 10000) + (int(numversion_tok[1]) * 100) + int(numversion_tok[2])
+        else:
+            qlc_version = (int(numversion_tok[0]) * 10000) + (int(numversion_tok[1]) * 100)
+
+    return qlc_version
+
+###########################################################################################
+# validate_fx_creator
+#
+# Validate the fixture creator field
+#
+# absname: the absolute file path
+# xmlObj The fixture XML object
+###########################################################################################
+
+def validate_fx_creator(absname, xmlObj, errNum):
+    global namespace
+    root = xmlObj.getroot()
 
     ##################################### CHECK CREATOR #################################
 
@@ -315,15 +348,6 @@ def validate_fixture(path, filename):
         name_tag = creator_tag.find('{' + namespace + '}Name')
         version_tag = creator_tag.find('{' + namespace + '}Version')
 
-        numversion_tok = re.findall('\d+', version_tag.text)
-        #print("Definition version: " + version_tag.text)
-
-        # extract a unified number from the QLC version string
-        if len(numversion_tok) == 3:
-            qlc_version = (int(numversion_tok[0]) * 10000) + (int(numversion_tok[1]) * 100) + int(numversion_tok[2])
-        else:
-            qlc_version = (int(numversion_tok[0]) * 10000) + (int(numversion_tok[1]) * 100)
-
         if author_tag is None:
             print(absname + ": Author tag not found")
             errNum += 1
@@ -340,7 +364,29 @@ def validate_fixture(path, filename):
                         print(absname + ": URLs or emails not allowed in author tag")
                         errNum += 1
 
-    ################################ CHECK FIXTURE GENERALS ##############################
+        if version_tag is None:
+            print(absname + ": Version tag not found")
+            errNum += 1
+        else:
+            qlc_version = getDefinitionVersion(xmlObj)
+            if (qlc_version == 0):
+                print(absname + ": Version tag not in version semantics")
+                errNum += 1
+
+    return errNum
+
+###########################################################################################
+# validate_fx_generals
+#
+# Validate the fixture general fields
+#
+# absname: the absolute file path
+# xmlObj The fixture XML object
+###########################################################################################
+
+def validate_fx_generals(absname, xmlObj, errNum):
+    global namespace
+    root = xmlObj.getroot()
 
     manuf_tag = root.find('{' + namespace + '}Manufacturer')
     model_tag = root.find('{' + namespace + '}Model')
@@ -356,15 +402,172 @@ def validate_fixture(path, filename):
         print(absname + ": Invalid type detected")
         errNum += 1
 
-    ##################################### CHECK CHANNELS #################################
+    return errNum
+
+###########################################################################################
+# validate_fx_modes
+#
+# Validate the fixture modes
+#
+# absname: the absolute file path
+# xmlObj The fixture XML object
+# hasPan True if the fixture has a PAN mode
+# hasTilt True if the fixture has a TILT mode
+# channelNames List of channel names
+###########################################################################################
+
+def validate_fx_modes(absname, xmlObj, hasPan, hasTilt, channelNames, colorRgb):
+    global namespace
+    root = xmlObj.getroot()
+    errNum = 0
+    hasPan = False
+    hasTilt = False
+    hasZoom = False
+
+    modeCount = 0
+    global_phy_tag = root.find('{' + namespace + '}Physical')
+
+    for mode in root.findall('{' + namespace + '}Mode'):
+        modeCount += 1
+        modeName = ""
+        if 'Name' not in mode.attrib:
+            print(absname + ": mode name attribute not found")
+            errNum += 1
+        else:
+            modeName = mode.attrib['Name']
+
+        if not modeName:
+            print(absname + ": Empty mode name detected")
+            errNum += 1
+
+        # better to skip this for now. Still too many errors
+        qlc_version = getDefinitionVersion(xmlObj)
+        if qlc_version >= 41207 and 'mode' in modeName.lower():
+            print(absname + ":" + modeName + ": word 'mode' found in mode name (version " + str(qlc_version) +")")
+            errNum += 1
+
+        modeChanCount = 0
+        modeHeadsCount = 0
+
+        for mchan in mode.findall('{' + namespace + '}Channel'):
+            mchan_no = "0"
+            if 'Number' not in mchan.attrib:
+                print(absname + ": mode channel number attribute not found")
+                errNum += 1
+            else:
+                mchan_no = mchan.attrib['Number']
+                #print(absname + ":" + modeName + ": Channel " + mchan_no + "): " + mchan.text)
+
+            if mchan.text is None:
+                print(absname + ":" + modeName + ": Empty channel name found. This definition won't work.")
+                errNum += 1
+            else:
+                if mchan.text not in channelNames:
+                    print(absname + ":" + modeName + ":" + mchan_no + ": Channel " + mchan.text + " doesn't exist. This definition won't work.")
+                    errNum += 1
+
+            if 'ActsOn' in mchan.attrib:
+                if mchan.attrib["ActsOn"] is mchan_no:
+                    print(absname + ":" + modeName + ":" + mchan_no + ": Channel cannot act on itself. Leave it blank.")
+                    errNum += 1
+
+            modeChanCount += 1
+
+        if modeChanCount == 0:
+            print(absname + ":" + modeName + ": No channel found in mode")
+            errNum += 1
+
+        for mchan in mode.findall('{' + namespace + '}Head'):
+            modeHeadsCount += 1
+
+        if modeHeadsCount == 1:
+            print(absname + ":" + modeName + ": Single head found. Not allowed")
+            errNum += 1
+
+#        if modeHeadsCount > 3:
+#            print(absname + ":" + modeName + ": Heads found: " + str(modeHeadsCount))
+
+        phy_tag = mode.find('{' + namespace + '}Physical')
+        if phy_tag is None and global_phy_tag is None:
+            print(absname + ":" + modeName + ": No physical data found")
+            errNum += 1
+
+        errNum = check_physical(absname, mode, hasPan, hasTilt, hasZoom, errNum)
+
+    if modeCount == 0:
+        print(absname + ": Invalid fixture. No modes found!")
+        errNum += 1
+
+    return errNum
+
+###########################################################################################
+# validate_color_codes
+#
+# Validate color codes for given color names
+#
+# propName: Reference to the property for error messages
+# fxColorName: the TX color name
+# fxColorCode: the TX color code
+# qlc_version: Version of the ficture file
+# errNum: Current number of errors
+# colorRgb: Hash array with names mapping to color codes
+###########################################################################################
+
+def validate_color_codes(propName, fxColorName, fxColorCode, qlc_version, errNum, colorRgb):
+    targetCode = ""
+
+    # Normalize name and code
+    fxSearchName = fxColorName.title()
+    fxSearchCode = fxColorCode.lower()
+
+    # Try to find the code for the given name
+    if fxSearchName in colorRgb["nameToRgb"]:
+         targetCode = colorRgb["nameToRgb"][fxSearchName]
+    else:
+        # Search for alternative color name from potential list
+        if fxSearchName in colorRgb["nameToRgb"]:
+            targetCode = colorRgb["nameToRgb"][fxSearchName + " 1"]
+        # else the string cannot be aligned to a known color code.
+
+    if targetCode != "":
+        # Name could be mapped to a code.
+        if fxSearchCode != targetCode:
+            # try to find alternative color code for color name
+            alternativeMsg = ""
+            if fxSearchCode in colorRgb["rgbToName"]:
+                alternativeMsg = ", the name for given FX color code is " + colorRgb["rgbToName"][fxSearchCode]
+
+            if qlc_version >= 41206 or alternativeMsg != "":
+                print(propName + ": FX color " + fxColorName + " (" + fxColorCode + ") should have color code " + targetCode + alternativeMsg)
+                errNum += 1
+
+    return errNum
+
+###########################################################################################
+# validate_fx_channels
+#
+# Validate the fixture channels
+#
+# absname: the absolute file path
+# xmlObj The fixture XML object
+###########################################################################################
+
+def validate_fx_channels(absname, xmlObj, errNum, colorRgb):
+    global namespace
+    root = xmlObj.getroot()
+    hasPan = False
+    hasTilt = False
+    hasZoom = False
+    needSave = False
 
     chCount = 0
     channelNames = []
+    qlc_version = getDefinitionVersion(xmlObj)
 
     for channel in root.findall('{' + namespace + '}Channel'):
         chName = ""
         chPreset = ""
-        if not 'Name' in channel.attrib:
+        if 'Name' not in channel.attrib:
             print(absname + ": Invalid channel. No name specified")
             errNum += 1
         else:
@@ -379,16 +582,16 @@ def validate_fixture(path, filename):
         groupByte = -1
 
         if not chPreset and childrenCount == 0:
-            print(absname + "/" + chName + ": Invalid channel. Not a preset and no capabilities found")
+            print(absname + ":" + chName + ": Invalid channel. Not a preset and no capabilities found")
             errNum += 1
 
         if not chPreset and group_tag is None:
-            print(absname + "/" + chName + ": Invalid channel. Not a preset and no group tag found")
+            print(absname + ":" + chName + ": Invalid channel. Not a preset and no group tag found")
             errNum += 1
 
         if group_tag is not None:
             if not group_tag.text:
-                print(absname + "/" + chName + ": Invalid channel. Empty group tag detected")
+                print(absname + ":" + chName + ": Invalid channel. Empty group tag detected")
                 errNum += 1
             else:
                 if group_tag.text == 'Pan':
@@ -396,8 +599,8 @@ def validate_fixture(path, filename):
                 if group_tag.text == 'Tilt':
                     hasTilt = True
 
-            if not 'Byte' in group_tag.attrib:
-                print(absname + "/" + chName + ": Invalid channel. Group byte attribute not found")
+            if 'Byte' not in group_tag.attrib:
+                print(absname + ":" + chName + ": Invalid channel. Group byte attribute not found")
                 errNum += 1
             else:
                 groupByte = group_tag.attrib['Byte']
@@ -407,28 +610,26 @@ def validate_fixture(path, filename):
                 hasPan = True
             if chPreset == "PositionTilt" or chPreset == "PositionTiltFine" or chPreset == "PositionYAxis":
                 hasTilt = True
+            if chPreset == "BeamZoomSmallBig" or chPreset == "BeamZoomBigSmall" or chPreset == "BeamZoomFine":
+                hasZoom = True
             # no need to go further if this is a preset
             chCount += 1
             continue
 
         # check the word 'fine' against control byte
         if groupByte == 0 and 'fine' in chName:
-            print(absname + "/" + chName + ": control byte should be set to Fine (LSB)")
+            print(absname + ":" + chName + ": control byte should be set to Fine (LSB)")
             errNum += 1
 
         ################################# CHECK CAPABILITIES ##############################
-
-        rangeMin = 255
-        rangeMax = 0
         lastMax = -1
         capCount = 0
 
         for capability in channel.findall('{' + namespace + '}Capability'):
-
             newResSyntax = False
             capName = capability.text
             if not capName:
-                print(absname + "/" + chName + ": Capability with no description detected")
+                print(absname + ":" + chName + ": Capability with no description detected")
                 errNum += 1
 
             # check capabilities overlapping
@@ -438,13 +639,17 @@ def validate_fixture(path, filename):
             #print("Min: " + str(currMin) + ", max: " + str(currMax))
 
             if currMin <= lastMax:
-                print(absname + "/" + chName + "/" + capName + ": Overlapping values detected " + str(currMin) + "/" + str(lastMax))
+                print(absname + ":" + chName + "/" + capName + ": Overlapping values detected " + str(currMin) + "/" + str(lastMax))
                 errNum += 1
 
-            # disabled for now. 710 errors with this !
-            #if currMin != lastMax + 1:
-            #    print(absname + "/" + chName + "/" + capName + ": Non contiguous range detected " + str(currMin) + "/" + str(lastMax))
-            #    errNum += 1
+            if currMin > currMax:
+                print(absname + ":" + chName + "/" + capName + ": Min larger than Max " + str(currMin) + "/" + str(currMax))
+                errNum += 1
+
+            # Evaluate contiguous ranges
+            if currMin != lastMax + 1:
+                print(absname + ":" + chName + "/" + capName + ": Non contiguous range detected " + str(lastMax) + "/" + str(currMin))
+                errNum += 1
 
             lastMax = currMax
 
@@ -456,7 +661,7 @@ def validate_fixture(path, filename):
                 newResSyntax = True
 
             if resource.startswith('/'):
-                print(absname + "/" + chName + "/" + capName + ": Absolute paths not allowed in resources")
+                print(absname + ":" + chName + "/" + capName + ": Absolute paths not allowed in resources")
                 errNum += 1
 
             # check the actual existence of a gobo. If possible, migrate to SVG
@@ -470,7 +675,7 @@ def validate_fixture(path, filename):
                     goboPath = os.getcwd() + "/../gobos/" + resource
 
                     if not os.path.isfile(goboPath):
-                        print(absname + "/" + chName + "/" + capName + ": Non existing gobo file detected (" + resource + ")")
+                        print(absname + ":" + chName + "/" + capName + ": Non existing gobo file detected (" + resource + ")")
                         errNum += 1
                     else:
                         needSave = True
@@ -479,10 +684,58 @@ def validate_fixture(path, filename):
                         else:
                             capability.set('Res', resource)
 
+            # Check for consistent color codes for given color names
+            hexPattern = re.compile(r'^#([0-9a-fA-F]){6}$')
+            capPreset = capability.attrib.get('Preset', "")
+            if capPreset == "ColorMacro" or capPreset == "ColorDoubleMacro":
+                res = capability.attrib.get('Res1', "")
+                if not re.search(hexPattern, res):
+                    alternativeMsg = ""
+                    if capability.text in colorRgb["nameToRgb"]:
+                        alternativeMsg = " (" + colorRgb["nameToRgb"][capability.text] + ")"
+                    print(absname + ":" + chName + "/" + capName + ": Res1 (" + res + ") required to start with '#' in Preset=ColorMacro and ColorDoubleMacro" + alternativeMsg)
+                    errNum += 1
+                errNum = validate_color_codes(
+                    absname + ":" + chName + "/" + capName + "/Res1",
+                    capability.text,
+                    res,
+                    qlc_version,
+                    errNum,
+                    colorRgb)
+            if capPreset == "ColorDoubleMacro":
+                res = capability.attrib.get('Res2', "")
+                if not re.search(hexPattern, res):
+                    print(absname + ":" + chName + "/" + capName + ": Res2 (" + res + ") required to start with '#' in ColorDoubleMacro")
+                    errNum += 1
+                errNum = validate_color_codes(
+                    absname + ":" + chName + "/" + capName + "/Res2",
+                    capability.text,
+                    res,
+                    qlc_version,
+                    errNum,
+                    colorRgb)
+            elif capPreset == "":
+                res = capability.attrib.get('Res1', "__.NOT._.SET.___")
+                if res != "__.NOT._.SET.___":
+                    print(absname + ":" + chName + "/" + capName + ": Res1 not evaluated withour Preset=")
+                    errNum += 1
+                res = capability.attrib.get('Res2', "__.NOT._.SET.___")
+                if res != "__.NOT._.SET.___":
+                    print(absname + ":" + chName + "/" + capName + ": Res2 not evaluated withour Preset=")
+                    errNum += 1
+            if capPreset == "ColorMacro" and capability.attrib.get('Res2', "") != "":
+                print(absname + ":" + chName + "/" + capName + ": Res2 not evaluated in Preset=ColorMacro")
+                errNum += 1
+
             capCount += 1
 
+        # Evaluate completeness of ranges
+        if 255 != lastMax:
+            print(absname + ":" + chName + ": Incomplete range detected " + str(currMax) + "/255")
+            errNum += 1
+
         if capCount == 0:
-            print(absname + "/" + chName + ": Channel has no capabilities")
+            print(absname + ":" + chName + ": Channel has no capabilities")
             errNum += 1
 
         chCount += 1
@@ -492,82 +745,52 @@ def validate_fixture(path, filename):
         errNum += 1
 
     ###################################### CHECK MODES ###################################
-
-    modeCount = 0
-    global_phy_tag = root.find('{' + namespace + '}Physical')
-
-    for mode in root.findall('{' + namespace + '}Mode'):
-
-        modeName = ""
-
-        if not 'Name' in mode.attrib:
-            print(absname + ": mode name attribute not found")
-            errNum += 1
-        else:
-            modeName = mode.attrib['Name']
-
-        if not modeName:
-            print(absname + ": Empty mode name detected")
-            errNum += 1
-
-        # better to skip this for now. Still too many errors
-        #if qlc_version >= 41100 and 'mode' in modeName.lower():
-        #    print(absname + "/" + modeName + ": word 'mode' found in mode name")
-        #    errNum += 1
-
-        modeChanCount = 0
-        modeHeadsCount = 0
-
-        for mchan in mode.findall('{' + namespace + '}Channel'):
-
-            if mchan.text is None:
-                print(absname + "/" + modeName + ": Empty channel name found. This definition won't work.")
-                errNum += 1
-            else:
-                if not mchan.text in channelNames:
-                    print(absname + "/" + modeName + ": Channel " + mchan.text + " doesn't exist. This definition won't work.")
-                    errNum += 1
-
-            modeChanCount += 1
-
-        if modeChanCount == 0:
-            print(absname + "/" + modeName + ": No channel found in mode")
-            errNum += 1
-
-        for mchan in mode.findall('{' + namespace + '}Head'):
-            modeHeadsCount += 1
-
-        if modeHeadsCount == 1:
-            print(absname + "/" + modeName + ": Single head found. Not allowed")
-            errNum += 1
-
-#        if modeHeadsCount > 3:
-#            print(absname + "/" + modeName + ": Heads found: " + str(modeHeadsCount))
-
-        phy_tag = mode.find('{' + namespace + '}Physical')
-
-        if phy_tag is None and global_phy_tag is None:
-            print(absname + "/" + modeName + ": No physical data found")
-            errNum += 1
-
-        errNum += check_physical(absname, mode, hasPan, hasTilt)
-
-        modeCount += 1
-
-    if modeCount == 0:
-        print(absname + ": Invalid fixture. No modes found!")
-        errNum += 1
-
-    ################################ CHECK GLOBAL PHYSICAL ################################
-
-    errNum += check_physical(absname, root, hasPan, hasTilt)
+    errNum += validate_fx_modes(absname, xmlObj, hasPan, hasTilt, channelNames, colorRgb)
 
     if needSave:
-        print("Saving back " + filename + "...")
+        print("Saving back " + absname + "...")
         xmlFile = open(absname, "w")
-        xmlFile.write(etree.tostring(root, pretty_print=True, xml_declaration=True, encoding="UTF-8", doctype="<!DOCTYPE FixtureDefinition>"))
+        xmlFile.write(etree.tostring(root, pretty_print=True, xml_declaration=True, encoding="UTF-8", doctype="<!DOCTYPE FixtureDefinition>").decode('utf8'))
+        if (sys.version_info >= (3, 0)):
+            xmlFile.write(etree.tostring(root, pretty_print=True, xml_declaration=True, encoding="UTF-8", doctype="<!DOCTYPE FixtureDefinition>"))
+        else:
+            # python 2.x
+            xmlFile.write(etree.tostring(root, pretty_print=True, xml_declaration=True, encoding="UTF-8", doctype="<!DOCTYPE FixtureDefinition>"))
         xmlFile.close()
 
+    return errNum, hasPan, hasTilt, hasZoom
+
+###########################################################################################
+# validate_fixture
+#
+# Check the syntax of a definition and reports errors if found
+#
+# absname: the absolute file path
+###########################################################################################
+
+def validate_fixture(absname, colorRgb):
+    parser = etree.XMLParser(ns_clean=True, recover=True)
+    xmlObj = etree.parse(absname, parser=parser)
+    root = xmlObj.getroot()
+
+    global namespace
+    errNum = 0
+    hasPan = False
+    hasTilt = False
+    hasZoom = False
+
+    ##################################### CHECK CREATOR #################################
+    errNum = validate_fx_creator(absname, xmlObj, errNum)
+
+    ################################ CHECK FIXTURE GENERALS ##############################
+    errNum = validate_fx_generals(absname, xmlObj, errNum)
+
+    ##################################### CHECK CHANNELS #################################
+    errNum, hasPan, hasTilt, hasZoom = validate_fx_channels(absname, xmlObj, errNum, colorRgb)
+
+    ################################ CHECK GLOBAL PHYSICAL ################################
+    errNum = check_physical(absname, root, hasPan, hasTilt, hasZoom, errNum)
+
     return errNum
 
 ###########################################################################################
@@ -609,10 +832,35 @@ def createFixtureMap():
             #print(manufacturer.text + ", " + model.text)
             count += 1
 
-    xmlFile.write(etree.tostring(root, pretty_print=True, xml_declaration=True, encoding="UTF-8", doctype="<!DOCTYPE FixturesMap>"))
+    if (sys.version_info >= (3, 0)):
+        xmlFile.write(etree.tostring(root, pretty_print=True, xml_declaration=True, encoding="UTF-8", doctype="<!DOCTYPE FixturesMap>").decode('utf8'))
+    else:
+        # python 2.x
+        xmlFile.write(etree.tostring(root, pretty_print=True, xml_declaration=True, encoding="UTF-8", doctype="<!DOCTYPE FixturesMap>"))
     xmlFile.close()
     print("Fixtures in map: " + str(count))
 
+###########################################################################################
+# get_validation_files
+#
+# Get the files in the path to check the syntax of a definition and reports errors if found
+#
+# path: the source path with the fixtures to validate
+###########################################################################################
+
+def get_validation_files(path):
+    files = []
+
+    #print("Processing path " + path)
+    if os.path.isdir(path):
+        for direntry in sorted(os.listdir(path), key=lambda s: s.lower()):
+            files += get_validation_files(os.path.join(path, direntry))
+    else:
+        if os.path.isfile(path) and path.endswith('.qxf'):
+            files.append(path)
+
+    return files
+
 ###########################################################################################
 #
 #                                       MAIN
@@ -621,55 +869,70 @@ def createFixtureMap():
 
 parser = argparse.ArgumentParser(description='Unified Fixture tool.')
 parser.add_argument('--map', help='Create the Fixture map', action='store_true')
-parser.add_argument('--convert [source] [destination]', help='Convert an "old" syntax Fixture definition',
+parser.add_argument('--convert <source> <destination>', help='Convert an "old" syntax Fixture definition',
                     nargs='*', dest='convert')
-parser.add_argument('--validate [path]', help='Validate fixtures in the specified path',
+parser.add_argument('--validate [<path> ...]', help='Validate fixtures in the specified path',
                     nargs='*', dest='validate')
 args = parser.parse_args()
 
 print(args)
 
-if args.map:
-    createFixtureMap()
-elif args.convert:
-    if len(sys.argv) < 3:
-        print("Usage " + sys.argv[0] + "--convert [source folder] [destination folder]")
+if args.convert is not None:
+    print("Starting conversion")
+    if len(args.convert) < 2:
+        print("Usage " + sys.argv[0] + "--convert <source folder> <destination folder>")
         sys.exit()
 
-    path = sys.argv[2]
-    if len(sys.argv) > 3:
-        destpath = sys.argv[3]
-    else:
-        destpath = ""
+    path = sys.args.convert[1]
+    destpath = args.convert[2]
     print("Converting fixtures in " + path + "...")
 
     for filename in os.listdir(path):
-        if not filename.endswith('.qxf'): continue
+        if not filename.endswith('.qxf'):
+            continue
         print("Processing file " + filename)
 
         singleCapCount += update_fixture(path, filename, destpath)
 
     print("Scan done. Single cap found: " + str(singleCapCount))
-elif args.validate:
-    if len(sys.argv) < 2:
-        print("Usage " + sys.argv[0] + "--validate [path]")
-        sys.exit()
 
-    path = sys.argv[2]
+if args.map:
+    createFixtureMap()
+
+if args.validate is not None:
+    print("Starting validation")
+
+    rgbAbsname = os.path.join("..", "colorfilters", "namedrgb.qxcf")
+    rgbParser = etree.XMLParser(ns_clean=True, recover=True)
+    rgbObj = etree.parse(rgbAbsname, parser=rgbParser)
+    rgbRoot = rgbObj.getroot()
+
+    colorRgb = {}
+    colorRgb["nameToRgb"] = {}
+    colorRgb["rgbToName"] = {}
+    for colorEntry in rgbRoot.findall('{http://www.qlcplus.org/ColorFilters}Color'):
+        rgbCode = colorEntry.attrib['RGB'].lower()
+        colorName = colorEntry.attrib['Name'].title()
+        colorRgb["nameToRgb"][colorName] = rgbCode
+        colorRgb["rgbToName"][rgbCode] = colorName
+
+    paths = ["."]
+    if len(args.validate) >= 1:
+        paths = args.validate
 
     fileCount = 0
     errorCount = 0
+    files = []
 
-    for dirname in sorted(os.listdir(path), key=lambda s: s.lower()):
+    for path in paths:
+        files += get_validation_files(path)
 
-        if not os.path.isdir(dirname): continue
+    for file in files:
+        #print("Processing file " + filepath)
+        errorCount += validate_fixture(file, colorRgb)
 
-        for filename in sorted(os.listdir(dirname), key=lambda s: s.lower()):
-            if not filename.endswith('.qxf'): continue
+    print(str(len(files)) + " definitions processed. " + str(errorCount) + " errors detected")
 
-            #print("Processing file " + filename)
-            errorCount += validate_fixture(dirname, filename)
-            fileCount += 1
-
-    print(str(fileCount) + " definitions processed. " + str(errorCount) + " errors detected")
+    if errorCount != 0:
+        sys.exit(1)
 
