@@ -123,6 +123,9 @@ public:
 public:
     /** Get the currently selected item index, otherwise 0 */
     int getCurrentIndex();
+    /** Get the progress text of the selected item */
+    QString progressText();
+    double progressPercent();
 
 private:
     /** Get the index of the next item, based on the chaser direction */
@@ -177,6 +180,16 @@ public slots:
     /** Skip to the previous cue */
     void slotPreviousCue();
 
+    /** Called when m_runner skips to another step */
+    void slotCurrentStepChanged(int stepNumber);
+
+    /** Update cue step note */
+    void slotStepNoteChanged(int idx, QString note);
+
+signals:
+    /** progress percent value and text */
+    void progressStateChanged();
+
 private slots:
     /** Removes destroyed functions from the list */
     void slotFunctionRemoved(quint32 fid);
@@ -190,9 +203,6 @@ private slots:
     /** Update the step list at m_updateTimer timeout */
     void slotUpdateStepList();
 
-    /** Called when m_runner skips to another step */
-    void slotCurrentStepChanged(int stepNumber);
-
     /** Slot that is called whenever the current item changes (either by
         pressing the key binding or clicking an item with mouse) */
     void slotItemActivated(QTreeWidgetItem *item);
@@ -239,6 +249,10 @@ public:
 
     void setPlaybackLayout(PlaybackLayout layout);
     PlaybackLayout playbackLayout() const;
+signals:
+    void playbackButtonClicked();
+    void stopButtonClicked();
+    void playbackStatusChanged();
 
 private:
     /** ID of the Chaser this Cue List will be controlling */
@@ -273,6 +287,22 @@ public:
 
     FaderMode stringToFaderMode(QString modeStr);
     QString faderModeToString(FaderMode mode);
+    bool isSideFaderVisible();
+    bool sideFaderButtonChecked();
+    QString topPercentageValue();
+    QString bottomPercentageValue();
+    QString topStepValue();
+    QString bottomStepValue();
+    int sideFaderValue();
+    bool primaryTop();
+
+signals:
+    void sideFaderButtonToggled();
+    void sideFaderValueChanged();
+
+public slots:
+    void slotSideFaderButtonChecked(bool enable);
+    void slotSetSideFaderValue(int value);
 
 protected:
     void setFaderInfo(int index);
@@ -378,6 +408,8 @@ signals:
     /** Signal to webaccess */
     void stepChanged(int idx);
 
+    void stepNoteChanged(int idx, QString note);
+
 private:
     FunctionParent functionParent() const;
 
