@@ -26,15 +26,15 @@
 #include <QDebug>
 
 #include "vcspeeddialproperties.h"
-#include "vcpropertieseditor.h"
-#include "vcspeeddial.h"
 #include "vcspeeddialfunction.h"
+#include "vcpropertieseditor.h"
 #include "vcspeeddialpreset.h"
+#include "vcspeeddial.h"
+#include "flowlayout.h"
 #include "speeddial.h"
 #include "qlcmacros.h"
-#include "qlcfile.h"
 #include "function.h"
-#include "flowlayout.h"
+#include "qlcfile.h"
 
 #define UPDATE_TIMEOUT 50
 
@@ -166,7 +166,7 @@ VCSpeedDial::VCSpeedDial(QWidget* parent, Doc* doc)
 
 VCSpeedDial::~VCSpeedDial()
 {
-    foreach(VCSpeedDialPreset* preset, m_presets)
+    foreach (VCSpeedDialPreset* preset, m_presets)
     {
         delete preset;
     }
@@ -571,8 +571,8 @@ void VCSpeedDial::updateFeedback()
             QPushButton* button = reinterpret_cast<QPushButton*>(it.key());
             if (preset->m_inputSource.isNull() == false)
                 sendFeedback(button->isDown() ?
-                             preset->m_inputSource->upperValue() :
-                             preset->m_inputSource->lowerValue(),
+                             preset->m_inputSource->feedbackValue(QLCInputFeedback::UpperValue) :
+                             preset->m_inputSource->feedbackValue(QLCInputFeedback::LowerValue),
                              preset->m_inputSource);
         }
     }
@@ -917,7 +917,7 @@ bool VCSpeedDial::loadXML(QXmlStreamReader &root)
 
             infinitePreset->m_keySequence = stripKeySequence(QKeySequence(root.readElementText()));
         }
-        else if(root.name() == KXMLQLCVCSpeedDialPreset)
+        else if (root.name() == KXMLQLCVCSpeedDialPreset)
         {
             VCSpeedDialPreset preset(0xff);
             if (preset.loadXML(root))
@@ -1090,7 +1090,7 @@ bool VCSpeedDial::saveXML(QXmlStreamWriter *doc)
         speeddialfunction.saveXML(doc);
 
     // Presets
-    foreach(VCSpeedDialPreset *preset, presets())
+    foreach (VCSpeedDialPreset *preset, presets())
         preset->saveXML(doc);
 
     /* End the <SpeedDial> tag */
