@@ -39,16 +39,12 @@
 #include <QList>
 
 #include "qlcmacros.h"
-#include "qlcfile.h"
 
 #include "vcpropertieseditor.h"
 #include "vcxypadproperties.h"
-#include "qlcinputchannel.h"
-#include "virtualconsole.h"
 #include "ctkrangeslider.h"
 #include "mastertimer.h"
 #include "vcxypadarea.h"
-#include "inputpatch.h"
 #include "flowlayout.h"
 #include "vcxypad.h"
 #include "fixture.h"
@@ -209,7 +205,7 @@ void VCXYPad::enableWidgetUI(bool enable)
         it.setValue(fxi);
     }
 
-    foreach(QWidget *presetBtn, m_presets.keys())
+    foreach (QWidget *presetBtn, m_presets.keys())
         presetBtn->setEnabled(enable);
 
     /* Reset the changed flag in m_area so that the pad won't immediately set a value
@@ -232,6 +228,13 @@ VCWidget* VCXYPad::createCopy(VCWidget* parent)
         xypad = NULL;
     }
 
+    for (QHash<QWidget*, VCXYPadPreset*>::iterator it = m_presets.begin();
+            it != m_presets.end(); ++it)
+    {
+        VCXYPadPreset *preset = it.value();
+        xypad->addPreset(*preset);
+    }
+
     return xypad;
 }
 
@@ -429,7 +432,7 @@ void VCXYPad::writeScenePositions(MasterTimer *timer, QList<Universe *> universe
     uchar tiltCoarse = uchar(qFloor(pt.y()));
     uchar tiltFine = uchar((pt.y() - qFloor(pt.y())) * 256);
 
-    foreach(SceneChannel sc, m_sceneChannels)
+    foreach (SceneChannel sc, m_sceneChannels)
     {
         if (sc.m_universe >= (quint32)universes.count())
             continue;
@@ -551,7 +554,7 @@ void VCXYPad::slotRangeValueChanged()
     m_area->update();
     if (QObject::sender() == m_hRangeSlider)
         sendFeedback(m_hRangeSlider->maximumValue(), heightInputSourceId);
-    else if(QObject::sender() == m_vRangeSlider)
+    else if (QObject::sender() == m_vRangeSlider)
         sendFeedback(m_vRangeSlider->maximumValue(), widthInputSourceId);
 }
 
@@ -563,7 +566,7 @@ void VCXYPad::slotUniverseWritten(quint32 idx, const QByteArray &universeData)
     {
         QMap <quint32, QPointF> fxMap;
 
-        foreach(SceneChannel sc, m_sceneChannels)
+        foreach (SceneChannel sc, m_sceneChannels)
         {
             if (sc.m_universe != idx)
                 continue;
@@ -588,7 +591,7 @@ void VCXYPad::slotUniverseWritten(quint32 idx, const QByteArray &universeData)
             fxMap[sc.m_fixture] = QPointF(x, y);
         }
 
-        foreach(QPointF pt, fxMap.values())
+        foreach (QPointF pt, fxMap.values())
         {
             if (invertedAppearance())
                 pt.setY(256 - pt.y());
@@ -607,7 +610,7 @@ void VCXYPad::slotUniverseWritten(quint32 idx, const QByteArray &universeData)
 
             qreal x(-1), y(-1);
             fixture.readDMX(universeData, x, y);
-            if( x != -1.0 && y != -1.0)
+            if (x != -1.0 && y != -1.0)
             {
                 if (invertedAppearance())
                     y = qreal(1) - y;
@@ -630,7 +633,7 @@ void VCXYPad::addPreset(const VCXYPadPreset &preset)
 {
     QString label = preset.m_name;
 
-    if(label.isEmpty())
+    if (label.isEmpty())
     {
         qDebug() << "VCXYPad Preset label empty. Not adding it";
         return;
@@ -687,6 +690,16 @@ QList<VCXYPadPreset *> VCXYPad::presets() const
     return presets;
 }
 
+QMap<quint32,QString> VCXYPad::presetsMap() const
+{
+    QMap<quint32,QString> map;
+
+    foreach (VCXYPadPreset *control, m_presets.values())
+        map.insert(control->m_id, VCXYPadPreset::typeToString(control->m_type));
+
+    return map;
+}
+
 void VCXYPad::slotPresetClicked(bool checked)
 {
     if (mode() == Doc::Design)
@@ -740,7 +753,7 @@ void VCXYPad::slotPresetClicked(bool checked)
             {
                 cBtn->setChecked(false);
                 if (cPr->m_inputSource.isNull() == false)
-                    sendFeedback(cPr->m_inputSource->lowerValue(), cPr->m_inputSource);
+                    sendFeedback(cPr->m_inputSource->feedbackValue(QLCInputFeedback::LowerValue), cPr->m_inputSource);
             }
         }
         else if (cPr->m_type == VCXYPadPreset::EFX ||
@@ -750,7 +763,7 @@ void VCXYPad::slotPresetClicked(bool checked)
             {
                 cBtn->setChecked(false);
                 if (cPr->m_inputSource.isNull() == false)
-                    sendFeedback(cPr->m_inputSource->lowerValue(), cPr->m_inputSource);
+                    sendFeedback(cPr->m_inputSource->feedbackValue(QLCInputFeedback::LowerValue), cPr->m_inputSource);
             }
         }
         else
@@ -759,12 +772,12 @@ void VCXYPad::slotPresetClicked(bool checked)
             {
                 cBtn->setDown(false);
                 if (cPr->m_inputSource.isNull() == false)
-                    sendFeedback(cPr->m_inputSource->lowerValue(), cPr->m_inputSource);
+                    sendFeedback(cPr->m_inputSource->feedbackValue(QLCInputFeedback::LowerValue), cPr->m_inputSource);
             }
         }
         cBtn->blockSignals(false);
         if (cPr->m_inputSource.isNull() == false)
-            sendFeedback(cPr->m_inputSource->lowerValue(), cPr->m_inputSource);
+            sendFeedback(cPr->m_inputSource->feedbackValue(QLCInputFeedback::LowerValue), cPr->m_inputSource);
     }
 
     if (preset->m_type == VCXYPadPreset::EFX)
@@ -805,7 +818,7 @@ void VCXYPad::slotPresetClicked(bool checked)
         connect(m_efx, SIGNAL(durationChanged(uint)), this, SLOT(slotEFXDurationChanged(uint)));
 
         if (preset->m_inputSource.isNull() == false)
-            sendFeedback(preset->m_inputSource->upperValue(), preset->m_inputSource);
+            sendFeedback(preset->m_inputSource->feedbackValue(QLCInputFeedback::UpperValue), preset->m_inputSource);
     }
     else if (preset->m_type == VCXYPadPreset::Scene)
     {
@@ -819,7 +832,7 @@ void VCXYPad::slotPresetClicked(bool checked)
         m_scene = qobject_cast<Scene*>(f);
         m_sceneChannels.clear();
 
-        foreach(SceneValue scv, m_scene->values())
+        foreach (SceneValue scv, m_scene->values())
         {
             Fixture *fixture = m_doc->fixture(scv.fxi);
             if (fixture == NULL)
@@ -833,7 +846,7 @@ void VCXYPad::slotPresetClicked(bool checked)
             SceneChannel sChan;
             sChan.m_universe = fixture->universe();
             sChan.m_fixture = fixture->id();
-            sChan.m_channel = fixture->address() + scv.channel;
+            sChan.m_channel = scv.channel;
             sChan.m_group = ch->group();
             sChan.m_subType = ch->controlByte();
             m_sceneChannels.append(sChan);
@@ -847,7 +860,7 @@ void VCXYPad::slotPresetClicked(bool checked)
         m_scene->start(m_doc->masterTimer(), functionParent());
 
         if (preset->m_inputSource.isNull() == false)
-            sendFeedback(preset->m_inputSource->upperValue(), preset->m_inputSource);
+            sendFeedback(preset->m_inputSource->feedbackValue(QLCInputFeedback::UpperValue), preset->m_inputSource);
     }
     else if (preset->m_type == VCXYPadPreset::Position)
     {
@@ -858,7 +871,7 @@ void VCXYPad::slotPresetClicked(bool checked)
         m_area->setPosition(preset->m_dmxPos);
         m_area->repaint();
         if (preset->m_inputSource.isNull() == false)
-            sendFeedback(preset->m_inputSource->upperValue(), preset->m_inputSource);
+            sendFeedback(preset->m_inputSource->feedbackValue(QLCInputFeedback::UpperValue), preset->m_inputSource);
         btn->blockSignals(true);
         btn->setDown(true);
         btn->blockSignals(false);
@@ -1170,7 +1183,7 @@ bool VCXYPad::loadXML(QXmlStreamReader &root)
             if (fxi.loadXML(root) == true)
                 appendFixture(fxi);
         }
-        else if(root.name() == KXMLQLCVCXYPadPreset)
+        else if (root.name() == KXMLQLCVCXYPadPreset)
         {
             VCXYPadPreset preset(0xff);
             if (preset.loadXML(root))
@@ -1262,7 +1275,7 @@ bool VCXYPad::saveXML(QXmlStreamWriter *doc)
     }
 
     // Presets
-    foreach(VCXYPadPreset *preset, presets())
+    foreach (VCXYPadPreset *preset, presets())
         preset->saveXML(doc);
 
     /* End the >XYPad> tag */
